@@ -174,10 +174,6 @@ public class FormatData_da extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
-               "BC",
-               "BE",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE d. MMMM y G",
                "d. MMMM y G",
@@ -194,20 +190,15 @@ public class FormatData_da extends ListResourceBundle {
                "AM",
                "PM",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "f\u00f8r R.O.C.",
                "Minguo",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
-               "",
-               "AH",
-            };
         final String metaValue_calendarname_gregorian = "gregoriansk kalender";
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
             { "field.year", "\u00e5r" },
             { "calendarname.islamic-umalqura", "islamisk kalender (Umm al-Qura)" },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
@@ -215,7 +206,7 @@ public class FormatData_da extends ListResourceBundle {
             { "calendarname.islamic-civil", "verdslig islamisk kalender" },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "fKr",
@@ -291,9 +282,8 @@ public class FormatData_da extends ListResourceBundle {
             { "calendarname.roc", "kalender for Republikken Kina" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
             { "field.month", "m\u00e5ned" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "sekund" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -306,6 +296,8 @@ public class FormatData_da extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamisk kalender" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -335,13 +327,13 @@ public class FormatData_da extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_roc_AmPmMarkers },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "tidszone" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "Eras", metaValue_long_Eras },
             { "roc.DayNames", metaValue_DayNames },
@@ -350,7 +342,6 @@ public class FormatData_da extends ListResourceBundle {
             { "field.weekday", "ugedag" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "timezone.hourFormat", "+HH.mm;-HH.mm" },
@@ -359,7 +350,6 @@ public class FormatData_da extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
             { "field.week", "uge" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -376,15 +366,15 @@ public class FormatData_da extends ListResourceBundle {
                     "0\u00a0t",
                     "00\u00a0t",
                     "000\u00a0t",
-                    "0\u00a0mio",
-                    "00\u00a0mio",
-                    "000\u00a0mio",
-                    "0\u00a0mia",
-                    "00\u00a0mia",
-                    "000\u00a0mia",
-                    "0\u00a0bio",
-                    "00\u00a0bio",
-                    "000\u00a0bio",
+                    "0\u00a0mio'.'",
+                    "00\u00a0mio'.'",
+                    "000\u00a0mio'.'",
+                    "0\u00a0mia'.'",
+                    "00\u00a0mia'.'",
+                    "000\u00a0mia'.'",
+                    "0\u00a0bio'.'",
+                    "00\u00a0bio'.'",
+                    "000\u00a0bio'.'",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
@@ -393,7 +383,7 @@ public class FormatData_da extends ListResourceBundle {
                     "EEEE 'den' d. MMMM y",
                     "d. MMMM y",
                     "d. MMM y",
-                    "dd/MM/y",
+                    "dd.MM.y",
                 }
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
@@ -401,7 +391,6 @@ public class FormatData_da extends ListResourceBundle {
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
             { "standalone.DayNames", metaValue_DayNames },
             { "field.hour", "time" },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
             { "calendarname.buddhist", "buddhistisk kalender" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
