@@ -70,6 +70,10 @@ import java.util.ListResourceBundle;
 public class FormatData_en_001 extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_AmPmMarkers = new String[] {
+               "am",
+               "pm",
+            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, d MMMM y G",
                "d MMMM y G",
@@ -82,16 +86,28 @@ public class FormatData_en_001 extends ListResourceBundle {
                "d MMM y GGGG",
                "dd/MM/y G",
             };
+        final String[] metaValue_japanese_narrow_AmPmMarkers = new String[] {
+               "AM",
+               "pm",
+            };
         final Object[][] data = new Object[][] {
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
+            { "AmPmMarkers", metaValue_AmPmMarkers },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
+            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "field.dayperiod", "am/pm" },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "DatePatterns",
                 new String[] {
                     "EEEE, d MMMM y",
@@ -100,6 +116,13 @@ public class FormatData_en_001 extends ListResourceBundle {
                     "dd/MM/y",
                 }
             },
+            { "narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
+            { "roc.narrow.AmPmMarkers", metaValue_japanese_narrow_AmPmMarkers },
+            { "field.dayperiod", "am/pm" },
+            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
         return data;
     }
