@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -170,9 +170,9 @@ public class FormatData_fi extends ListResourceBundle {
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
-               "BE",
+               "buddhalainen aika",
             };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "cccc d. MMMM y G",
@@ -186,13 +186,17 @@ public class FormatData_fi extends ListResourceBundle {
                "d.M.y GGGG",
                "d.M.y G",
             };
-        final String[] metaValue_roc_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "ennen Kiinan tasavaltaa",
+               "Minguo",
+            };
+        final String[] metaValue_java_time_roc_Eras = new String[] {
                "e. Kiinan tasav.",
                "Minguo",
             };
-        final String[] metaValue_islamic_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
-               "AH",
+               "hid\u017eran j\u00e4lkeen",
             };
         final String metaValue_calendarname_gregorian = "gregoriaaninen kalenteri";
         final Object[][] data = new Object[][] {
@@ -200,7 +204,6 @@ public class FormatData_fi extends ListResourceBundle {
             { "field.year", "vuosi" },
             { "calendarname.islamic-umalqura", "islamilainen Umm al-Qura -kalenteri" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.gmtFormat", "UTC{0}" },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -210,18 +213,13 @@ public class FormatData_fi extends ListResourceBundle {
             { "calendarname.islamic-civil", "islamilainen siviilikalenteri, perjantai-epookki" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "eKr",
                     "jKr",
                 }
             },
-            { "roc.long.Eras",
-                new String[] {
-                    "ennen Kiinan tasavaltaa",
-                    "Minguo",
-                }
-            },
             { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "timezone.regionFormat.standard", "{0} (normaaliaika)" },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -291,9 +289,8 @@ public class FormatData_fi extends ListResourceBundle {
             { "calendarname.roc", "Kiinan tasavallan kalenteri" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_Eras },
             { "field.month", "kuukausi" },
-            { "roc.Eras", metaValue_roc_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "sekunti" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -306,6 +303,8 @@ public class FormatData_fi extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "islamilainen kalenteri" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations",
@@ -326,6 +325,25 @@ public class FormatData_fi extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "aikavy\u00f6hyke: {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 tuhat",
+                    "00 tuhatta",
+                    "000 tuhatta",
+                    "0 miljoona",
+                    "00 miljoonaa",
+                    "000 miljoonaa",
+                    "0 miljardi",
+                    "00 miljardia",
+                    "000 miljardia",
+                    "0 biljoona",
+                    "00 biljoonaa",
+                    "000 biljoonaa",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -333,18 +351,15 @@ public class FormatData_fi extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras",
-                new String[] {
-                    "BC",
-                    "buddhalainen aika",
-                }
-            },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "aikavy\u00f6hyke" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
@@ -368,12 +383,7 @@ public class FormatData_fi extends ListResourceBundle {
             },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras",
-                new String[] {
-                    "",
-                    "hid\u017eran j\u00e4lkeen",
-                }
-            },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "timezone.hourFormat", "+H.mm;-H.mm" },
@@ -382,7 +392,6 @@ public class FormatData_fi extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_Eras },
             { "field.week", "viikko" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -391,6 +400,25 @@ public class FormatData_fi extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0t'.'",
+                    "00\u00a0t'.'",
+                    "000\u00a0t'.'",
+                    "0\u00a0milj'.'",
+                    "00\u00a0milj'.'",
+                    "000\u00a0milj'.'",
+                    "0\u00a0mrd'.'",
+                    "00\u00a0mrd'.'",
+                    "000\u00a0mrd'.'",
+                    "0\u00a0bilj'.'",
+                    "00\u00a0bilj'.'",
+                    "000\u00a0bilj'.'",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} (kes\u00e4aika)" },
             { "DatePatterns",
@@ -416,7 +444,6 @@ public class FormatData_fi extends ListResourceBundle {
                 }
             },
             { "field.hour", "tunti" },
-            { "islamic.narrow.Eras", metaValue_islamic_Eras },
             { "calendarname.buddhist", "buddhalainen kalenteri" },
             { "standalone.MonthNames",
                 new String[] {
@@ -436,6 +463,7 @@ public class FormatData_fi extends ListResourceBundle {
                 }
             },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
