@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -172,22 +172,12 @@ public class FormatData_mk extends ListResourceBundle {
                "HH:mm:ss",
                "HH:mm",
             };
-        final String[] metaValue_DateTimePatterns = new String[] {
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-               "{1} {0}",
-            };
         final String[] metaValue_buddhist_QuarterNarrows = new String[] {
                "1",
                "2",
                "3",
                "4",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
-               "BC",
-               "BE",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
                "EEEE, dd MMMM y '\u0433'. G",
                "dd MMMM y '\u0433'. G",
@@ -200,13 +190,13 @@ public class FormatData_mk extends ListResourceBundle {
                "dd.M.y GGGG",
                "dd.M.y G",
             };
-        final String[] metaValue_roc_Eras = new String[] {
-               "\u043f\u0440. \u0420.\u041a.",
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
+               "\u043f\u0440\u0435\u0434 \u0420.\u041a.",
                "\u043c\u0438\u043d\u0433\u0443\u043e",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
-               "",
-               "AH",
+        final String[] metaValue_java_time_roc_Eras = new String[] {
+               "\u043f\u0440. \u0420.\u041a.",
+               "\u043c\u0438\u043d\u0433\u0443\u043e",
             };
         final String metaValue_calendarname_gregorian = "\u0413\u0440\u0435\u0433\u043e\u0440\u0438\u0458\u0430\u043d\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440";
         final Object[][] data = new Object[][] {
@@ -214,7 +204,6 @@ public class FormatData_mk extends ListResourceBundle {
             { "field.year", "\u0433\u043e\u0434\u0438\u043d\u0430" },
             { "calendarname.islamic-umalqura", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 (\u0423\u043c \u0430\u043b-\u041a\u0443\u0440\u0430)" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -224,12 +213,7 @@ public class FormatData_mk extends ListResourceBundle {
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
             { "narrow.Eras", metaValue_Eras },
-            { "roc.long.Eras",
-                new String[] {
-                    "\u043f\u0440\u0435\u0434 \u0420.\u041a.",
-                    "\u043c\u0438\u043d\u0433\u0443\u043e",
-                }
-            },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "japanese.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "calendarname.japanese", "\u0408\u0430\u043f\u043e\u043d\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
@@ -255,7 +239,14 @@ public class FormatData_mk extends ListResourceBundle {
             { "islamic.DayNames", metaValue_DayNames },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "buddhist.MonthNames", metaValue_MonthNames },
-            { "DateTimePatterns", metaValue_DateTimePatterns },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
             { "narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "latn.NumberElements",
                 new String[] {
@@ -300,9 +291,8 @@ public class FormatData_mk extends ListResourceBundle {
             { "calendarname.roc", "\u041c\u0438\u043d\u0433\u0443\u043e-\u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
             { "field.month", "\u043c\u0435\u0441\u0435\u0446" },
-            { "roc.Eras", metaValue_roc_Eras },
+            { "roc.Eras", metaValue_java_time_roc_Eras },
             { "field.second", "\u0441\u0435\u043a\u0443\u043d\u0434\u0430" },
             { "DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNarrows", metaValue_DayNarrows },
@@ -315,10 +305,31 @@ public class FormatData_mk extends ListResourceBundle {
             },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "\u0418\u0441\u043b\u0430\u043c\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "timezone.regionFormat", "\u0412\u0440\u0435\u043c\u0435 \u0432\u043e {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0438\u043b\u0458\u0430\u0434\u0430",
+                    "00 \u0438\u043b\u0458\u0430\u0434\u0430",
+                    "000 \u0438\u043b\u0458\u0430\u0434\u0430",
+                    "0 \u043c\u0438\u043b\u0438\u043e\u043d",
+                    "00 \u043c\u0438\u043b\u0438\u043e\u043d",
+                    "000 \u043c\u0438\u043b\u0438\u043e\u043d",
+                    "0 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
+                    "00 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
+                    "000 \u043c\u0438\u043b\u0438\u0458\u0430\u0440\u0434\u0430",
+                    "0 \u0431\u0438\u043b\u0438\u043e\u043d",
+                    "00 \u0431\u0438\u043b\u0438\u043e\u043d",
+                    "000 \u0431\u0438\u043b\u0438\u043e\u043d",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -327,12 +338,12 @@ public class FormatData_mk extends ListResourceBundle {
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_Eras },
             { "field.zone", "\u0432\u0440\u0435\u043c\u0435\u043d\u0441\u043a\u0430 \u0437\u043e\u043d\u0430" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "Eras", metaValue_Eras },
@@ -341,10 +352,8 @@ public class FormatData_mk extends ListResourceBundle {
             { "islamic.abbreviated.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "field.weekday", "\u0434\u0435\u043d \u043e\u0434 \u043d\u0435\u0434\u0435\u043b\u0430\u0442\u0430" },
-            { "islamic.DateTimePatterns", metaValue_DateTimePatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "japanese.DayNames", metaValue_DayNames },
@@ -352,9 +361,7 @@ public class FormatData_mk extends ListResourceBundle {
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
             { "field.week", "\u0441\u0435\u0434\u043c\u0438\u0446\u0430" },
-            { "buddhist.DateTimePatterns", metaValue_DateTimePatterns },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
             { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
@@ -362,6 +369,25 @@ public class FormatData_mk extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0438\u043b\u0458'.'",
+                    "00\u00a0\u0438\u043b\u0458'.'",
+                    "000\u00a0\u0438\u043b\u0458'.'",
+                    "0\u00a0\u043c\u0438\u043b'.'",
+                    "00\u00a0\u043c\u0438\u043b'.'",
+                    "000\u00a0\u041c",
+                    "0\u00a0\u043c\u0438\u043b\u0458'.'",
+                    "00\u00a0\u043c\u0438\u043b\u0458'.'",
+                    "000\u00a0\u043c\u0458'.'",
+                    "0\u00a0\u0431\u0438\u043b'.'",
+                    "00\u00a0\u0431\u0438\u043b'.'",
+                    "000\u00a0\u0431\u0438\u043b'.'",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "DatePatterns",
                 new String[] {
@@ -393,7 +419,6 @@ public class FormatData_mk extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
             { "calendarname.buddhist", "\u0411\u0443\u0434\u0438\u0441\u0442\u0438\u0447\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "standalone.MonthNames", metaValue_MonthNames },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
