@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -201,14 +201,7 @@ public class FormatData_tk extends ListResourceBundle {
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "standalone.QuarterAbbreviations",
-                new String[] {
-                    "1\u00c7",
-                    "2\u00c7",
-                    "3\u00c7",
-                    "Q4",
-                }
-            },
+            { "standalone.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.QuarterNames", metaValue_QuarterNames },
             { "roc.MonthNarrows", metaValue_MonthNarrows },
             { "islamic.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
@@ -270,7 +263,7 @@ public class FormatData_tk extends ListResourceBundle {
             { "field.minute", "minut" },
             { "field.era", "era" },
             { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "field.dayperiod", "\u00f6\u00fdl\u00e4nden \u00f6\u0148/\u00f6\u00fdl\u00e4nden so\u0148" },
+            { "field.dayperiod", "g\u00fcnortadan \u00f6\u0148/g\u00fcnortadan so\u0148" },
             { "standalone.MonthNarrows", metaValue_MonthNarrows },
             { "calendarname.roc", "Minguo senenamasy" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
@@ -294,7 +287,7 @@ public class FormatData_tk extends ListResourceBundle {
                 new String[] {
                     "\u00ddan",
                     "Few",
-                    "Mart",
+                    "Mar",
                     "Apr",
                     "Ma\u00fd",
                     "I\u00fdun",
@@ -308,6 +301,25 @@ public class FormatData_tk extends ListResourceBundle {
                 }
             },
             { "timezone.regionFormat", "{0} wagty" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 m\u00fc\u0148",
+                    "00 m\u00fc\u0148",
+                    "000 m\u00fc\u0148",
+                    "0 million",
+                    "00 million",
+                    "000 million",
+                    "0 milliard",
+                    "00 milliard",
+                    "000 milliard",
+                    "0 trillion",
+                    "00 trillion",
+                    "000 trillion",
+                }
+            },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -345,6 +357,25 @@ public class FormatData_tk extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0m\u00fc\u0148",
+                    "00\u00a0m\u00fc\u0148",
+                    "000\u00a0m\u00fc\u0148",
+                    "0\u00a0mln",
+                    "00\u00a0mln",
+                    "000\u00a0mln",
+                    "0\u00a0mlrd",
+                    "00\u00a0mlrd",
+                    "000\u00a0mlrd",
+                    "0\u00a0trln",
+                    "00\u00a0trln",
+                    "000\u00a0trln",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "{0} tomusky wagty" },
             { "DatePatterns",
