@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -331,7 +331,8 @@ public class CurrencyNames_fy extends OpenListResourceBundle {
             { "uyu", "Uruguayaanske peso" },
             { "uzs", "Oezbekistaanske sum" },
             { "veb", "Fenezolaanske bolivar (1871\u20132008)" },
-            { "vef", "Fenezolaanske bolivar" },
+            { "vef", "Fenezolaanske bolivar (2008\u20132018)" },
+            { "ves", "Fenezolaanske bolivar" },
             { "vnd", "Fietnameeske dong" },
             { "vnn", "Alde Fietnameeske dong (1978\u20131985)" },
             { "vuv", "Vanuatuaanske vatu" },
