@@ -358,7 +358,8 @@ public class CurrencyNames_km extends OpenListResourceBundle {
             { "usd", "\u178a\u17bb\u179b\u17d2\u179b\u17b6\u179a\u200b\u17a2\u17b6\u1798\u17c1\u179a\u17b7\u1780" },
             { "uyu", "\u1794\u17c9\u17c1\u179f\u17bc\u17a2\u17ca\u17bb\u1799\u179a\u17bc\u17a0\u17d2\u1782\u17b6\u1799" },
             { "uzs", "\u179f\u17bb\u1798\u17a2\u17ca\u17bc\u1794\u17c1\u1782\u17b8\u179f\u17d2\u1790\u17b6\u1793" },
-            { "vef", "\u1794\u17ca\u17bc\u179b\u17b8\u179c\u17c9\u17b6\u200b\u179c\u17c9\u17c1\u178e\u17c1\u179f\u17ca\u17bb\u1799\u17a2\u17c1\u17a1\u17b6" },
+            { "vef", "\u1794\u17ca\u17bc\u179b\u17b8\u179c\u17c9\u17b6\u200b\u179c\u17c9\u17c1\u178e\u17c1\u179f\u17ca\u17bb\u1799\u17a2\u17c1\u17a1\u17b6 (2008\u20132018)" },
+            { "ves", "\u1794\u17ca\u17bc\u179b\u17b8\u179c\u17c9\u17b6\u200b\u179c\u17c9\u17c1\u178e\u17c1\u179f\u17ca\u17bb\u1799\u17a2\u17c1\u17a1\u17b6" },
             { "vnd", "\u178a\u17bb\u1784\u200b\u179c\u17c0\u178f\u178e\u17b6\u1798" },
             { "vuv", "\u179c\u17c9\u17b6\u1791\u17bc\u179c\u17c9\u17b6\u1793\u17bc\u17a2\u17b6\u1791\u17bc" },
             { "wst", "\u178f\u17b6\u17a1\u17b6\u200b\u179f\u17b6\u1798\u17d0\u179a" },
