@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -359,7 +359,8 @@ public class CurrencyNames_mn extends OpenListResourceBundle {
             { "usd", "\u0430\u043c\u0435\u0440\u0438\u043a \u0434\u043e\u043b\u043b\u0430\u0440" },
             { "uyu", "\u0443\u0440\u0443\u0433\u0432\u0430\u0439\u043d \u043f\u0435\u0441\u043e" },
             { "uzs", "\u0443\u0437\u0431\u0435\u043a\u0438\u0439\u043d \u0441\u043e\u043c" },
-            { "vef", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0438\u0439\u043d \u0431\u043e\u043b\u0438\u0432\u0430\u0440" },
+            { "vef", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0438\u0439\u043d \u0431\u043e\u043b\u0438\u0432\u0430\u0440 (2008\u20132018)" },
+            { "ves", "\u0432\u0435\u043d\u0435\u0441\u0443\u044d\u043b\u0438\u0439\u043d \u0431\u043e\u043b\u0438\u0432\u0430\u0440" },
             { "vnd", "\u0432\u044c\u0435\u0442\u043d\u0430\u043c\u044b\u043d \u0434\u043e\u043d\u0433" },
             { "vuv", "\u0432\u0430\u043d\u0443\u0430\u0442\u0443\u0433\u0438\u0439\u043d \u0432\u0430\u0442\u0443" },
             { "wst", "\u0441\u0430\u043c\u043e\u0430\u0433\u0438\u0439\u043d \u0442\u0430\u043b\u0430" },
