@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -152,6 +152,7 @@ public class CurrencyNames_or extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -204,6 +205,7 @@ public class CurrencyNames_or extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WST" },
             { "YER", "YER" },
@@ -355,7 +357,8 @@ public class CurrencyNames_or extends OpenListResourceBundle {
             { "usd", "\u0b2f\u0b41\u0b15\u0b4d\u0b24\u0b30\u0b3e\u0b37\u0b4d\u0b1f\u0b4d\u0b30 \u0b21\u0b32\u0b3e\u0b30\u0b4d" },
             { "uyu", "\u0b09\u0b30\u0b41\u0b17\u0b41\u0b07\u0b5f\u0b3e\u0b28\u0b4d \u0b2a\u0b47\u0b38\u0b4b" },
             { "uzs", "\u0b09\u0b1c\u0b2c\u0b47\u0b15\u0b3f\u0b38\u0b4d\u0b24\u0b3e\u0b28\u0b40 \u0b38\u0b4b\u0b2e\u0b4d" },
-            { "vef", "\u0b2d\u0b47\u0b28\u0b47\u0b1c\u0b41\u0b0f\u0b32\u0b3e\u0b28\u0b4d \u0b2c\u0b4b\u0b32\u0b3f\u0b2d\u0b3e\u0b30\u0b4d" },
+            { "vef", "\u0b2d\u0b47\u0b28\u0b47\u0b1c\u0b41\u0b0f\u0b32\u0b3e\u0b28\u0b4d \u0b2c\u0b4b\u0b32\u0b3f\u0b2d\u0b3e\u0b30\u0b4d (2008\u20132018)" },
+            { "ves", "\u0b2d\u0b47\u0b28\u0b47\u0b1c\u0b41\u0b0f\u0b32\u0b3e\u0b28\u0b4d \u0b2c\u0b4b\u0b32\u0b3f\u0b2d\u0b3e\u0b30\u0b4d" },
             { "vnd", "\u0b2d\u0b40\u0b0f\u0b24\u0b28\u0b3e\u0b2e\u0b40\u0b5f \u0b21\u0b19\u0b4d\u0b17" },
             { "vuv", "\u0b2d\u0b3e\u0b28\u0b41\u0b06\u0b1f\u0b41 \u0b2d\u0b3e\u0b1f\u0b41" },
             { "wst", "\u0b38\u0b3e\u0b2e\u0b4b\u0b5f\u0b3f\u0b5f \u0b24\u0b3e\u0b32\u0b3e" },
