@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -72,263 +72,74 @@ public class CurrencyNames_zh extends OpenListResourceBundle {
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
             { "ADP", "ADP" },
-            { "AED", "AED" },
-            { "AFN", "AFN" },
-            { "ALK", "ALK" },
-            { "ALL", "ALL" },
-            { "AMD", "AMD" },
-            { "ANG", "ANG" },
-            { "AOA", "AOA" },
-            { "AOK", "AOK" },
-            { "AON", "AON" },
-            { "AOR", "AOR" },
-            { "ARA", "ARA" },
-            { "ARL", "ARL" },
-            { "ARM", "ARM" },
-            { "ARP", "ARP" },
-            { "ARS", "ARS" },
-            { "ATS", "ATS" },
+            { "AFA", "AFA" },
             { "AUD", "AU$" },
-            { "AWG", "AWG" },
-            { "AZM", "AZM" },
-            { "AZN", "AZN" },
             { "BAD", "BAD" },
-            { "BAM", "BAM" },
             { "BAN", "BAN" },
-            { "BBD", "BBD" },
-            { "BDT", "BDT" },
-            { "BEC", "BEC" },
-            { "BEF", "BEF" },
-            { "BEL", "BEL" },
             { "BGL", "BGL" },
             { "BGM", "BGM" },
-            { "BGN", "BGN" },
             { "BGO", "BGO" },
-            { "BHD", "BHD" },
-            { "BIF", "BIF" },
-            { "BMD", "BMD" },
             { "BND", "BND" },
-            { "BOB", "BOB" },
-            { "BOL", "BOL" },
-            { "BOP", "BOP" },
-            { "BOV", "BOV" },
-            { "BRB", "BRB" },
-            { "BRC", "BRC" },
-            { "BRE", "BRE" },
-            { "BRN", "BRN" },
-            { "BRR", "BRR" },
-            { "BRZ", "BRZ" },
-            { "BSD", "BSD" },
-            { "BTN", "BTN" },
-            { "BWP", "BWP" },
+            { "BUK", "BUK" },
             { "BYB", "BYB" },
-            { "BYN", "BYN" },
-            { "BYR", "BYR" },
-            { "BZD", "BZD" },
-            { "CDF", "CDF" },
-            { "CHE", "CHE" },
-            { "CHF", "CHF" },
-            { "CHW", "CHW" },
-            { "CLE", "CLE" },
-            { "CLF", "CLF" },
-            { "CLP", "CLP" },
             { "CNH", "CNH" },
             { "CNY", "\uffe5" },
-            { "COP", "COP" },
-            { "COU", "COU" },
-            { "CRC", "CRC" },
             { "CSD", "CSD" },
             { "CSK", "CSK" },
-            { "CUC", "CUC" },
-            { "CUP", "CUP" },
-            { "CVE", "CVE" },
-            { "CYP", "CYP" },
-            { "CZK", "CZK" },
-            { "DDM", "DDM" },
-            { "DEM", "DEM" },
-            { "DJF", "DJF" },
-            { "DKK", "DKK" },
-            { "DOP", "DOP" },
-            { "DZD", "DZD" },
-            { "ECS", "ECS" },
-            { "ECV", "ECV" },
-            { "EEK", "EEK" },
-            { "EGP", "EGP" },
-            { "ERN", "ERN" },
             { "ESA", "ESA" },
             { "ESB", "ESB" },
             { "ESP", "ESP" },
-            { "ETB", "ETB" },
-            { "FIM", "FIM" },
-            { "FJD", "FJD" },
-            { "FKP", "FKP" },
-            { "FRF", "FRF" },
-            { "GEK", "GEK" },
-            { "GEL", "GEL" },
-            { "GHC", "GHC" },
-            { "GHS", "GHS" },
-            { "GIP", "GIP" },
-            { "GMD", "GMD" },
-            { "GNF", "GNF" },
-            { "GNS", "GNS" },
-            { "GQE", "GQE" },
             { "GRD", "GRD" },
-            { "GTQ", "GTQ" },
-            { "GWE", "GWE" },
-            { "GWP", "GWP" },
-            { "GYD", "GYD" },
-            { "HNL", "HNL" },
             { "HRD", "HRD" },
-            { "HRK", "HRK" },
-            { "HTG", "HTG" },
-            { "HUF", "HUF" },
             { "IDR", "IDR" },
-            { "IEP", "IEP" },
-            { "ILP", "ILP" },
             { "ILR", "ILS" },
-            { "IQD", "IQD" },
-            { "IRR", "IRR" },
             { "ISJ", "ISJ" },
-            { "ISK", "ISK" },
             { "ITL", "ITL" },
-            { "JMD", "JMD" },
-            { "JOD", "JOD" },
-            { "KES", "KES" },
-            { "KGS", "KGS" },
-            { "KHR", "KHR" },
-            { "KMF", "KMF" },
-            { "KPW", "KPW" },
+            { "KRH", "KRH" },
+            { "KRO", "KRO" },
             { "KRW", "\uffe6" },
-            { "KWD", "KWD" },
-            { "KYD", "KYD" },
-            { "KZT", "KZT" },
-            { "LAK", "LAK" },
-            { "LBP", "LBP" },
-            { "LKR", "LKR" },
-            { "LRD", "LRD" },
-            { "LSL", "LSL" },
-            { "LTL", "LTL" },
-            { "LTT", "LTT" },
-            { "LUC", "LUC" },
-            { "LUF", "LUF" },
-            { "LUL", "LUL" },
-            { "LVL", "LVL" },
-            { "LVR", "LVR" },
-            { "LYD", "LYD" },
-            { "MAD", "MAD" },
-            { "MAF", "MAF" },
-            { "MCF", "MCF" },
             { "MDC", "MDC" },
-            { "MDL", "MDL" },
-            { "MGA", "MGA" },
-            { "MGF", "MGF" },
-            { "MKD", "MKD" },
             { "MKN", "MKN" },
-            { "MLF", "MLF" },
-            { "MMK", "MMK" },
-            { "MNT", "MNT" },
-            { "MOP", "MOP" },
-            { "MRO", "MRO" },
             { "MTL", "MTL" },
             { "MTP", "MTP" },
-            { "MUR", "MUR" },
-            { "MVR", "MVR" },
-            { "MWK", "MWK" },
+            { "MVP", "MVP" },
             { "MXP", "MXP" },
             { "MXV", "MXV" },
-            { "MYR", "MYR" },
-            { "MZE", "MZE" },
-            { "MZM", "MZM" },
-            { "MZN", "MZN" },
-            { "NAD", "NAD" },
-            { "NGN", "NGN" },
             { "NIC", "NIC" },
-            { "NIO", "NIO" },
-            { "NLG", "NLG" },
-            { "NOK", "NOK" },
-            { "NPR", "NPR" },
-            { "OMR", "OMR" },
-            { "PAB", "PAB" },
-            { "PEI", "PEI" },
-            { "PEN", "PEN" },
-            { "PES", "PES" },
-            { "PGK", "PGK" },
-            { "PHP", "PHP" },
-            { "PKR", "PKR" },
-            { "PLN", "PLN" },
             { "PLZ", "PLZ" },
             { "PTE", "PTE" },
-            { "PYG", "PYG" },
-            { "QAR", "QAR" },
-            { "RHD", "RHD" },
             { "ROL", "ROL" },
-            { "RON", "RON" },
-            { "RSD", "RSD" },
-            { "RUB", "RUB" },
             { "RUR", "RUR" },
-            { "RWF", "RWF" },
-            { "SAR", "SAR" },
-            { "SBD", "SBD" },
-            { "SCR", "SCR" },
-            { "SDD", "SDD" },
-            { "SDG", "SDG" },
-            { "SDP", "SDP" },
-            { "SEK", "SEK" },
-            { "SGD", "SGD" },
-            { "SHP", "SHP" },
             { "SIT", "SIT" },
             { "SKK", "SKK" },
-            { "SLL", "SLL" },
-            { "SOS", "SOS" },
-            { "SRD", "SRD" },
-            { "SRG", "SRG" },
-            { "SSP", "SSP" },
-            { "STD", "STD" },
             { "SUR", "SUR" },
             { "SVC", "SVC" },
-            { "SYP", "SYP" },
-            { "SZL", "SZL" },
-            { "THB", "THB" },
-            { "TJR", "TJR" },
-            { "TJS", "TJS" },
-            { "TMM", "TMM" },
-            { "TMT", "TMT" },
-            { "TND", "TND" },
-            { "TOP", "TOP" },
-            { "TRL", "TRL" },
-            { "TRY", "TRY" },
-            { "TTD", "TTD" },
-            { "TZS", "TZS" },
-            { "UAH", "UAH" },
+            { "TPE", "TPE" },
             { "UAK", "UAK" },
-            { "UGS", "UGS" },
-            { "UGX", "UGX" },
             { "USN", "USN" },
             { "USS", "USS" },
-            { "UYI", "UYI" },
-            { "UYP", "UYP" },
-            { "UYU", "UYU" },
-            { "UZS", "UZS" },
-            { "VEB", "VEB" },
-            { "VEF", "VEF" },
-            { "VUV", "VUV" },
-            { "WST", "WST" },
-            { "XEU", "XEU" },
-            { "YDD", "YDD" },
-            { "YER", "YER" },
+            { "UYW", "UYW" },
+            { "VNN", "VNN" },
+            { "XAG", "XAG" },
+            { "XAU", "XAU" },
+            { "XBA", "XBA" },
+            { "XBB", "XBB" },
+            { "XBC", "XBC" },
+            { "XBD", "XBD" },
+            { "XDR", "XDR" },
+            { "XFO", "XFO" },
+            { "XFU", "XFU" },
+            { "XPD", "XPD" },
+            { "XPT", "XPT" },
+            { "XRE", "XRE" },
+            { "XSU", "XSU" },
+            { "XTS", "XTS" },
+            { "XUA", "XUA" },
+            { "XXX", "XXX" },
             { "YUD", "YUD" },
             { "YUM", "YUM" },
             { "YUN", "YUN" },
             { "YUR", "YUR" },
-            { "ZAL", "ZAL" },
-            { "ZAR", "ZAR" },
-            { "ZMK", "ZMK" },
-            { "ZMW", "ZMW" },
-            { "ZRN", "ZRN" },
-            { "ZRZ", "ZRZ" },
-            { "ZWD", "ZWD" },
-            { "ZWL", "ZWL" },
-            { "ZWR", "ZWR" },
             { "adp", "\u5b89\u9053\u5c14\u6bd4\u585e\u5854" },
             { "aed", "\u963f\u8054\u914b\u8fea\u62c9\u59c6" },
             { "afa", "\u963f\u5bcc\u6c57\u5c3c (1927\u20132002)" },
@@ -586,9 +397,11 @@ public class CurrencyNames_zh extends OpenListResourceBundle {
             { "uyi", "\u4e4c\u62c9\u572d\u6bd4\u7d22\uff08\u7d22\u5f15\u5355\u4f4d\uff09" },
             { "uyp", "\u4e4c\u62c9\u572d\u6bd4\u7d22 (1975\u20131993)" },
             { "uyu", "\u4e4c\u62c9\u572d\u6bd4\u7d22" },
+            { "uyw", "\u4e4c\u62c9\u572d\u7968\u9762\u5de5\u8d44\u6307\u6570\u5355\u4f4d" },
             { "uzs", "\u4e4c\u5179\u522b\u514b\u65af\u5766\u82cf\u59c6" },
             { "veb", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14 (1871\u20132008)" },
-            { "vef", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14" },
+            { "vef", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14 (2008\u20132018)" },
+            { "ves", "\u59d4\u5185\u745e\u62c9\u73bb\u5229\u74e6\u5c14" },
             { "vnd", "\u8d8a\u5357\u76fe" },
             { "vnn", "\u8d8a\u5357\u76fe (1978\u20131985)" },
             { "vuv", "\u74e6\u52aa\u963f\u56fe\u74e6\u56fe" },
@@ -610,7 +423,9 @@ public class CurrencyNames_zh extends OpenListResourceBundle {
             { "xpf", "\u592a\u5e73\u6d0b\u6cd5\u90ce" },
             { "xpt", "\u94c2" },
             { "xre", "RINET \u57fa\u91d1" },
+            { "xsu", "\u82cf\u514b\u96f7" },
             { "xts", "\u6d4b\u8bd5\u8d27\u5e01\u4ee3\u7801" },
+            { "xua", "\u975e\u6d32\u5f00\u53d1\u94f6\u884c\u8bb0\u8d26\u5355\u4f4d" },
             { "xxx", "\u672a\u77e5\u8d27\u5e01" },
             { "ydd", "\u4e5f\u95e8\u7b2c\u7eb3\u5c14" },
             { "yer", "\u4e5f\u95e8\u91cc\u4e9a\u5c14" },
