@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -137,7 +137,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "%%AREVELA", "\u0623\u0631\u0645\u0646\u064a\u0629 \u0634\u0631\u0642\u064a\u0629" },
             { "BA", "\u0627\u0644\u0628\u0648\u0633\u0646\u0629 \u0648\u0627\u0644\u0647\u0631\u0633\u0643" },
             { "BB", "\u0628\u0631\u0628\u0627\u062f\u0648\u0633" },
-            { "ceb", "\u0627\u0644\u0633\u064a\u0628\u0648\u0646\u064a\u0629" },
+            { "ceb", "\u0627\u0644\u0633\u064a\u0628\u064a\u0648\u0627\u0646\u064a\u0629" },
             { "BD", "\u0628\u0646\u063a\u0644\u0627\u062f\u064a\u0634" },
             { "kum", "\u0627\u0644\u0642\u0645\u0648\u0642\u064a\u0629" },
             { "BE", "\u0628\u0644\u062c\u064a\u0643\u0627" },
@@ -380,7 +380,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "MH", "\u062c\u0632\u0631 \u0645\u0627\u0631\u0634\u0627\u0644" },
             { "ale", "\u0627\u0644\u0623\u0644\u064a\u0648\u062a\u064a\u0629" },
             { "type.nu.vaii", "\u0623\u0631\u0642\u0627\u0645 \u0641\u0627\u064a" },
-            { "MK", "\u0645\u0642\u062f\u0648\u0646\u064a\u0627" },
+            { "MK", "\u0645\u0642\u062f\u0648\u0646\u064a\u0627 \u0627\u0644\u0634\u0645\u0627\u0644\u064a\u0629" },
             { "ML", "\u0645\u0627\u0644\u064a" },
             { "MM", "\u0645\u064a\u0627\u0646\u0645\u0627\u0631 (\u0628\u0648\u0631\u0645\u0627)" },
             { "MN", "\u0645\u0646\u063a\u0648\u0644\u064a\u0627" },
@@ -401,7 +401,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "MY", "\u0645\u0627\u0644\u064a\u0632\u064a\u0627" },
             { "MZ", "\u0645\u0648\u0632\u0645\u0628\u064a\u0642" },
             { "NA", "\u0646\u0627\u0645\u064a\u0628\u064a\u0627" },
-            { "202", "202" },
+            { "202", "\u0623\u0641\u0631\u064a\u0642\u064a\u0627 \u062c\u0646\u0648\u0628 \u0627\u0644\u0635\u062d\u0631\u0627\u0621 \u0627\u0644\u0643\u0628\u0631\u0649" },
             { "type.ca.hebrew", "\u0627\u0644\u062a\u0642\u0648\u064a\u0645 \u0627\u0644\u0639\u0628\u0631\u064a" },
             { "type.co.dictionary", "\u062a\u0631\u062a\u064a\u0628 \u0641\u0631\u0632 \u0627\u0644\u0642\u0627\u0645\u0648\u0633" },
             { "NC", "\u0643\u0627\u0644\u064a\u062f\u0648\u0646\u064a\u0627 \u0627\u0644\u062c\u062f\u064a\u062f\u0629" },
@@ -509,7 +509,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "SX", "\u0633\u0627\u0646\u062a \u0645\u0627\u0631\u062a\u0646" },
             { "SY", "\u0633\u0648\u0631\u064a\u0627" },
             { "yao", "\u0627\u0644\u064a\u0627\u0648" },
-            { "SZ", "\u0633\u0648\u0627\u0632\u064a\u0644\u0627\u0646\u062f" },
+            { "SZ", "\u0625\u0633\u0648\u0627\u062a\u064a\u0646\u064a" },
             { "arw", "\u0627\u0644\u0623\u0631\u0627\u0648\u0627\u0643\u064a\u0629" },
             { "yap", "\u0627\u0644\u064a\u0627\u0628\u064a\u0632" },
             { "TA", "\u062a\u0631\u064a\u0633\u062a\u0627\u0646 \u062f\u0627 \u0643\u0648\u0646\u0627" },
@@ -525,7 +525,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "TJ", "\u0637\u0627\u062c\u064a\u0643\u0633\u062a\u0627\u0646" },
             { "029", "\u0627\u0644\u0643\u0627\u0631\u064a\u0628\u064a" },
             { "TK", "\u062a\u0648\u0643\u064a\u0644\u0648" },
-            { "TL", "\u062a\u064a\u0645\u0648\u0631- \u0644\u064a\u0634\u062a\u064a" },
+            { "TL", "\u062a\u064a\u0645\u0648\u0631 - \u0644\u064a\u0634\u062a\u064a" },
             { "ybb", "\u064a\u0645\u0628\u0627" },
             { "type.co.searchjl", "\u0628\u062d\u062b \u0628\u0627\u0633\u062a\u062e\u062f\u0627\u0645 \u062d\u0631\u0641 \u0627\u0644\u0647\u0627\u0646\u063a\u0648\u0644 \u0627\u0644\u0633\u0627\u0643\u0646 \u0627\u0644\u0623\u0648\u0644" },
             { "TM", "\u062a\u0631\u0643\u0645\u0627\u0646\u0633\u062a\u0627\u0646" },
@@ -556,7 +556,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "UM", "\u062c\u0632\u0631 \u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629 \u0627\u0644\u0646\u0627\u0626\u064a\u0629" },
             { "UN", "\u0627\u0644\u0623\u0645\u0645 \u0627\u0644\u0645\u062a\u062d\u062f\u0629" },
             { "US", "\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629" },
-            { "haw", "\u0644\u063a\u0629 \u0623\u0647\u0644 \u0627\u0644\u0647\u0627\u0648\u0627\u064a" },
+            { "haw", "\u0644\u063a\u0629 \u0647\u0627\u0648\u0627\u064a" },
             { "%%1959ACAD", "\u0623\u0643\u0627\u062f\u064a\u0645\u064a" },
             { "type.co.gb2312han", "\u062a\u0631\u062a\u064a\u0628 \u0641\u0631\u0632 \u0627\u0644\u0635\u064a\u0646\u064a\u0629 \u0627\u0644\u0645\u0628\u0633\u0637\u0629 (GB2312)" },
             { "UY", "\u0623\u0648\u0631\u063a\u0648\u0627\u064a" },
@@ -590,6 +590,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "WS", "\u0633\u0627\u0645\u0648\u0627" },
             { "wal", "\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a\u0627" },
             { "was", "\u0627\u0644\u0648\u0627\u0634\u0648" },
+            { "XA", "XA" },
             { "war", "\u0627\u0644\u0648\u0627\u0631\u0627\u064a" },
             { "awa", "\u0627\u0644\u0623\u0648\u0627\u062f\u064a\u0629" },
             { "061", "\u0628\u0648\u0644\u064a\u0646\u064a\u0632\u064a\u0627" },
@@ -642,11 +643,11 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "Limb", "\u0627\u0644\u0644\u064a\u0645\u0628\u0648" },
             { "sad", "\u0627\u0644\u0633\u0627\u0646\u062f\u0627\u0648\u064a" },
             { "type.nu.roman", "\u0627\u0644\u0623\u0631\u0642\u0627\u0645 \u0627\u0644\u0631\u0648\u0645\u0627\u0646\u064a\u0629" },
-            { "sah", "\u0627\u0644\u0633\u0627\u062e\u064a\u0629" },
+            { "sah", "\u0627\u0644\u0633\u0627\u062e\u064a\u0651\u0629" },
             { "sam", "\u0627\u0644\u0622\u0631\u0627\u0645\u064a\u0629 \u0627\u0644\u0633\u0627\u0645\u0631\u064a\u0629" },
             { "saq", "\u0633\u0627\u0645\u0628\u0648\u0631\u0648" },
             { "sas", "\u0627\u0644\u0633\u0627\u0633\u0627\u0643" },
-            { "sat", "\u0627\u0644\u0633\u0627\u0646\u062a\u0627\u0644\u064a" },
+            { "sat", "\u0627\u0644\u0633\u0627\u0646\u062a\u0627\u0644\u064a\u0629" },
             { "Tfng", "\u0627\u0644\u062a\u064a\u0641\u064a\u0646\u0627\u063a" },
             { "jpr", "\u0627\u0644\u0641\u0627\u0631\u0633\u064a\u0629 \u0627\u0644\u064a\u0647\u0648\u062f\u064a\u0629" },
             { "type.d0.npinyin", "\u0631\u0642\u0645\u064a" },
@@ -876,7 +877,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "lv", "\u0627\u0644\u0644\u0627\u062a\u0641\u064a\u0629" },
             { "sog", "\u0627\u0644\u0633\u0648\u062c\u062f\u064a\u0646" },
             { "ListCompositionPattern", "{0}\u060c {1}" },
-            { "mg", "\u0627\u0644\u0645\u0627\u0644\u0627\u063a\u0627\u0634\u064a\u0629" },
+            { "mg", "\u0627\u0644\u0645\u0644\u063a\u0627\u0634\u064a" },
             { "mh", "\u0627\u0644\u0645\u0627\u0631\u0634\u0627\u0644\u064a\u0629" },
             { "type.co.ducet", "\u062a\u0631\u062a\u064a\u0628 \u0641\u0631\u0632 Unicode \u0627\u0644\u0627\u0641\u062a\u0631\u0627\u0636\u064a" },
             { "mi", "\u0627\u0644\u0645\u0627\u0648\u0631\u064a\u0629" },
@@ -893,7 +894,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "dsb", "\u0635\u0648\u0631\u0628\u064a\u0627 \u0627\u0644\u0633\u0641\u0644\u0649" },
             { "na", "\u0627\u0644\u0646\u0648\u0631\u0648" },
             { "type.co.search", "\u0628\u062d\u062b \u0644\u0623\u063a\u0631\u0627\u0636 \u0639\u0627\u0645\u0629" },
-            { "nb", "\u0628\u0648\u0643\u0645\u0648\u0644 \u0627\u0644\u0646\u0631\u0648\u064a\u062c\u064a\u0629" },
+            { "nb", "\u0627\u0644\u0646\u0631\u0648\u064a\u062c\u064a\u0629 \u0628\u0648\u0643\u0645\u0627\u0644" },
             { "nd", "\u0627\u0644\u0646\u062f\u064a\u0628\u064a\u0644 \u0627\u0644\u0634\u0645\u0627\u0644\u064a\u0629" },
             { "ne", "\u0627\u0644\u0646\u064a\u0628\u0627\u0644\u064a\u0629" },
             { "ng", "\u0627\u0644\u0646\u062f\u0648\u0646\u062c\u0627" },
@@ -908,7 +909,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "kac", "\u0627\u0644\u0643\u0627\u062a\u0634\u064a\u0646" },
             { "kab", "\u0627\u0644\u0642\u0628\u064a\u0644\u064a\u0629" },
             { "%%POLYTON", "\u0645\u062a\u0639\u062f\u062f \u0627\u0644\u0646\u063a\u0645\u0627\u062a" },
-            { "oc", "\u0627\u0644\u0623\u0648\u0643\u064a\u062a\u0627\u0646\u064a\u0629" },
+            { "oc", "\u0627\u0644\u0623\u0648\u0643\u0633\u064a\u062a\u0627\u0646\u064a\u0629" },
             { "kaj", "\u0627\u0644\u062c\u0648" },
             { "kam", "\u0627\u0644\u0643\u0627\u0645\u0628\u0627" },
             { "men", "\u0627\u0644\u0645\u064a\u0646\u062f" },
@@ -1052,7 +1053,7 @@ public class LocaleNames_ar extends OpenListResourceBundle {
             { "vo", "\u0644\u063a\u0629 \u0627\u0644\u0641\u0648\u0644\u0627\u0628\u0648\u0643" },
             { "syc", "\u0633\u0631\u064a\u0627\u0646\u064a\u0629 \u062a\u0642\u0644\u064a\u062f\u064a\u0629" },
             { "Osma", "\u0627\u0644\u0623\u0648\u0633\u0645\u0627\u0646\u064a\u0627" },
-            { "quc", "\u0643\u064a\u0634\u064a" },
+            { "quc", "\u0627\u0644\u0643\u064a\u0634\u064a\u0629" },
             { "gaa", "\u0627\u0644\u062c\u0627" },
             { "wa", "\u0627\u0644\u0648\u0644\u0648\u0646\u064a\u0629" },
             { "gag", "\u0627\u0644\u063a\u0627\u063a\u0648\u0632" },
