@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -137,7 +137,7 @@ public class LocaleNames_bg extends OpenListResourceBundle {
             { "BO", "\u0411\u043e\u043b\u0438\u0432\u0438\u044f" },
             { "BQ", "\u041a\u0430\u0440\u0438\u0431\u0441\u043a\u0430 \u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0438\u044f" },
             { "BR", "\u0411\u0440\u0430\u0437\u0438\u043b\u0438\u044f" },
-            { "BS", "\u0411\u0430\u0445\u0430\u043c\u0438" },
+            { "BS", "\u0411\u0430\u0445\u0430\u043c\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
             { "xog", "\u0441\u043e\u0433\u0430" },
             { "BT", "\u0411\u0443\u0442\u0430\u043d" },
             { "BV", "\u043e\u0441\u0442\u0440\u043e\u0432 \u0411\u0443\u0432\u0435" },
@@ -219,13 +219,13 @@ public class LocaleNames_bg extends OpenListResourceBundle {
             { "elx", "\u0435\u043b\u0430\u043c\u0438\u0442\u0441\u043a\u0438" },
             { "type.ca.gregorian", "\u0433\u0440\u0438\u0433\u043e\u0440\u0438\u0430\u043d\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440" },
             { "EZ", "\u0415\u0432\u0440\u043e\u0437\u043e\u043d\u0430" },
-            { "chy", "\u0447\u0435\u0439\u0435\u043d\u0441\u043a\u0438" },
+            { "chy", "\u0448\u0430\u0439\u0435\u043d\u0441\u043a\u0438" },
             { "type.nu.gujr", "\u0446\u0438\u0444\u0440\u0438 \u0432 \u0433\u0443\u0434\u0436\u0430\u0440\u0430\u0442\u0438" },
             { "Inds", "\u0425\u0430\u0440\u0430\u043f\u0441\u043a\u0430" },
             { "ady", "\u0430\u0434\u0438\u0433\u0435\u0439\u0441\u043a\u0438" },
             { "FI", "\u0424\u0438\u043d\u043b\u0430\u043d\u0434\u0438\u044f" },
             { "FJ", "\u0424\u0438\u0434\u0436\u0438" },
-            { "FK", "\u0424\u043e\u043b\u043a\u043b\u0435\u043d\u0434\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
+            { "FK", "\u0424\u043e\u043b\u043a\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
             { "FM", "\u041c\u0438\u043a\u0440\u043e\u043d\u0435\u0437\u0438\u044f" },
             { "key.va", "\u0412\u0430\u0440\u0438\u0430\u043d\u0442 \u043d\u0430 \u043b\u043e\u043a\u0430\u043b\u0430" },
             { "FO", "\u0424\u0430\u0440\u044c\u043e\u0440\u0441\u043a\u0438 \u043e\u0441\u0442\u0440\u043e\u0432\u0438" },
@@ -358,7 +358,7 @@ public class LocaleNames_bg extends OpenListResourceBundle {
             { "ale", "\u0430\u043b\u0435\u0443\u0442\u0441\u043a\u0438" },
             { "Thai", "\u0442\u0430\u0439\u0441\u043a\u0430" },
             { "type.nu.vaii", "\u0426\u0438\u0444\u0440\u0438 \u0432\u044a\u0432 \u0432\u0430\u0438" },
-            { "MK", "\u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u044f" },
+            { "MK", "\u0421\u0435\u0432\u0435\u0440\u043d\u0430 \u041c\u0430\u043a\u0435\u0434\u043e\u043d\u0438\u044f" },
             { "ML", "\u041c\u0430\u043b\u0438" },
             { "MM", "\u041c\u0438\u0430\u043d\u043c\u0430\u0440 (\u0411\u0438\u0440\u043c\u0430)" },
             { "MN", "\u041c\u043e\u043d\u0433\u043e\u043b\u0438\u044f" },
@@ -606,7 +606,7 @@ public class LocaleNames_bg extends OpenListResourceBundle {
             { "dak", "\u0434\u0430\u043a\u043e\u0442\u0441\u043a\u0438" },
             { "type.nu.fullwide", "\u0446\u0438\u0444\u0440\u0438 \u0441 \u043f\u044a\u043b\u043d\u0430 \u0448\u0438\u0440\u0438\u043d\u0430" },
             { "hit", "\u0445\u0438\u0442\u0441\u043a\u0438" },
-            { "dar", "\u0434\u0430\u0440\u0433\u0432\u0430" },
+            { "dar", "\u0434\u0430\u0440\u0433\u0438\u043d\u0441\u043a\u0438" },
             { "dav", "\u0442\u0430\u0438\u0442\u0430" },
             { "Maya", "\u0419\u0435\u0440\u043e\u0433\u043b\u0438\u0444\u0438 \u043d\u0430 \u041c\u0430\u0438\u0442\u0435" },
             { "lrc", "\u0441\u0435\u0432\u0435\u0440\u0435\u043d \u043b\u0443\u0440\u0438" },
@@ -755,7 +755,7 @@ public class LocaleNames_bg extends OpenListResourceBundle {
             { "gd", "\u0448\u043e\u0442\u043b\u0430\u043d\u0434\u0441\u043a\u0438 \u0433\u0430\u043b\u0441\u043a\u0438" },
             { "gl", "\u0433\u0430\u043b\u0438\u0441\u0438\u0439\u0441\u043a\u0438" },
             { "gn", "\u0433\u0443\u0430\u0440\u0430\u043d\u0438" },
-            { "bho", "\u0431\u043e\u0436\u043f\u0443\u0440\u0438" },
+            { "bho", "\u0431\u043e\u0434\u0436\u043f\u0443\u0440\u0438" },
             { "und", "\u043d\u0435\u043e\u043f\u0440\u0435\u0434\u0435\u043b\u0435\u043d" },
             { "type.ca.ethiopic-amete-alem", "\u0415\u0442\u0438\u043e\u043f\u0441\u043a\u0438 \u043a\u0430\u043b\u0435\u043d\u0434\u0430\u0440 \u0410\u043c\u0438\u0442 \u0410\u043b\u0435\u043c" },
             { "gu", metaValue_gu },
@@ -1098,7 +1098,7 @@ public class LocaleNames_bg extends OpenListResourceBundle {
             { "mul", "\u043c\u043d\u043e\u0433\u043e\u0435\u0437\u0438\u0447\u043d\u0438" },
             { "cad", "\u043a\u0430\u0434\u0434\u043e" },
             { "key.ms", "\u041c\u0435\u0440\u043d\u0430 \u0441\u0438\u0441\u0442\u0435\u043c\u0430" },
-            { "mus", "\u043a\u0440\u0438\u043a" },
+            { "mus", "\u043c\u0443\u0441\u043a\u043e\u0433\u0441\u043a\u0438" },
             { "Glag", "\u0413\u043b\u0430\u0433\u043e\u043b\u0438\u0447\u0435\u0441\u043a\u0430" },
             { "gil", "\u0433\u0438\u043b\u0431\u0435\u0440\u0442\u0441\u043a\u0438" },
             { "Cher", "\u0427\u0435\u0440\u043e\u043a\u0438" },
