@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -385,7 +385,7 @@ public class LocaleNames_nn extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "Marshall\u00f8yane" },
             { "ale", "aleutisk" },
-            { "MK", "Makedonia" },
+            { "MK", "Nord-Makedonia" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
