@@ -93,6 +93,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
         final String metaValue_ban = "balinesiska";
         final String metaValue_bax = "bamunska";
         final String metaValue_bug = "buginesiska";
+        final String metaValue_ccp = "chakma";
         final String metaValue_cop = "koptiska";
         final String metaValue_gez = "etiopiska";
         final String metaValue_got = "gotiska";
@@ -103,6 +104,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
         final String metaValue_peo = "fornpersiska";
         final String metaValue_phn = "feniciska";
         final String metaValue_saz = "saurashtra";
+        final String metaValue_sog = "sogdiska";
         final String metaValue_syr = "syriska";
         final String metaValue_uga = "ugaritiska";
         final String metaValue_vai = "vaj";
@@ -121,6 +123,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "Njiva-dialekt" },
             { "xmf", "mingrelianska" },
+            { "ccp", metaValue_ccp },
             { "egy", "fornegyptiska" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -167,6 +170,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "kum", "kumykiska" },
             { "BE", "Belgien" },
             { "gmh", "medelh\u00f6gtyska" },
+            { "Sogo", "gammalsogdiska" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgarien" },
             { "BH", "Bahrain" },
@@ -218,6 +222,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Pauc", "Pau Cin Hau-skrift" },
             { "vls", "v\u00e4stflaml\u00e4ndska" },
             { "%%RIGIK", "klassisk volap\u00fck" },
+            { "Sogd", metaValue_sog },
             { "DE", "Tyskland" },
             { "goh", "fornh\u00f6gtyska" },
             { "ace", "acehnesiska" },
@@ -425,6 +430,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "LK", "Sri Lanka" },
             { "akk", "akkadiska" },
             { "cop", metaValue_cop },
+            { "Hmnp", "nyiakeng puachue hmong" },
             { "LR", "Liberia" },
             { "esu", "centralalaskisk jupiska" },
             { "LS", "Lesotho" },
@@ -455,7 +461,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "MH", "Marshall\u00f6arna" },
             { "ale", "aleutiska" },
             { "type.nu.vaii", "vai-siffror" },
-            { "MK", "Makedonien" },
+            { "MK", "Nordmakedonien" },
             { "type.nu.mathdbl", "matematiska siffror med dubbelstreck" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
@@ -480,7 +486,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "MZ", "Mo\u00e7ambique" },
             { "Phli", "tidig pahlavi" },
             { "NA", "Namibia" },
-            { "202", "202" },
+            { "202", "Subsahariska Afrika" },
             { "type.ca.hebrew", "hebreisk kalender" },
             { "type.co.dictionary", "ordbokssorteringsordning" },
             { "NC", "Nya Kaledonien" },
@@ -514,6 +520,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%PETR1708", "1708 \u00e5rs stavning" },
             { "anp", "angika" },
             { "crs", "seychellisk kreol" },
+            { "type.nu.hmnp", "nyiakeng puachue hmong-siffror" },
             { "Xpeo", metaValue_peo },
             { "type.nu.hmng", "pahawh hmong-siffror" },
             { "PA", "Panama" },
@@ -565,6 +572,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "pnt", "pontiska" },
             { "Rjng", "rejang" },
             { "009", "Oceanien" },
+            { "Elym", "elymaiska" },
             { "%%SURSILV", "sursilvan-dialekt" },
             { "RO", "Rum\u00e4nien" },
             { "RS", "Serbien" },
@@ -679,6 +687,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "US", "USA" },
             { "haw", "hawaiiska" },
             { "%%1959ACAD", "1959 \u00e5rs stavning" },
+            { "%%IVANCHOV", "bulgariska i 1899 \u00e5rs stavning" },
             { "type.co.gb2312han", "gb2312-sorteringsordning" },
             { "UY", "Uruguay" },
             { "prg", "fornpreussiska" },
@@ -719,7 +728,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.mtei", "meetei mayek-siffror" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "fejkade accenter (f\u00f6r test)" },
             { "war", "waray" },
+            { "XB", "fejkad bidi (f\u00f6r test)" },
             { "awa", "awadhi" },
             { "061", "Polynesien" },
             { "%%KSCOR", "standardstavning" },
@@ -858,6 +869,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "sdh", "sydkurdiska" },
             { "ay", "aymara" },
             { "az", "azerbajdzjanska" },
+            { "Rohg", "hanifiska" },
             { "Khoj", "khojkiska" },
             { "%%OSOJS", "Osojane-dialekt" },
             { "%%UNIFON", "unifon-skrift" },
@@ -960,7 +972,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "sid", "sidamo" },
             { "fy", "v\u00e4stfrisiska" },
             { "ga", "iriska" },
+            { "Wcho", "wancho" },
             { "gd", "skotsk g\u00e4liska" },
+            { "Gong", "gunjalgondiska" },
             { "gl", "galiciska" },
             { "Gonm", "masaram-gondi" },
             { "gn", "guaran\u00ed" },
@@ -1068,8 +1082,8 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.lana", "tai tham hora-siffror" },
             { "lt", "litauiska" },
             { "lu", "luba-katanga" },
+            { "sog", metaValue_sog },
             { "lv", "lettiska" },
-            { "sog", "sogdiska" },
             { "mg", "malagassiska" },
             { "mh", "marshalliska" },
             { "type.co.ducet", "grundl\u00e4ggande Unicode-sorteringsordning" },
@@ -1087,7 +1101,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "mde", "maba" },
             { "dsb", "l\u00e5gsorbiska" },
             { "Armi", "imperisk arameiska" },
-            { "na", "nauriska" },
+            { "na", "nauruanska" },
             { "type.co.search", "allm\u00e4n s\u00f6kning" },
             { "nb", "norskt bokm\u00e5l" },
             { "nd", "nordndebele" },
@@ -1215,6 +1229,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%NEDIS", "natisonsk dialekt" },
             { "sv", "svenska" },
             { "sw", "swahili" },
+            { "type.nu.wcho", "wanchosiffror" },
             { "type.nu.hantfin", "traditionellt kinesiskt finansiellt stavade tal" },
             { "ibb", "ibibio" },
             { "iba", "ibanska" },
@@ -1239,9 +1254,9 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "japanskt stavade tal" },
             { "tr", "turkiska" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "shimaor\u00e9" },
-            { "Cakm", "chakma" },
             { "tt", "tatariska" },
             { "%%XSISTEMO", "x-system" },
             { "dyu", "dyula" },
@@ -1250,6 +1265,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%BISKE", "Bila-dialekt" },
             { "150", "Europa" },
             { "151", "\u00d6steuropa" },
+            { "type.nu.rohg", "hanifisiffror" },
             { "type.nu.mathsanb", "matematiska siffror i sans-serif fetstil" },
             { "154", "Nordeuropa" },
             { "dzg", "dazaga" },
@@ -1285,12 +1301,14 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.mathsans", "matematiska siffror i sans-serif" },
             { "Osma", "osmanja" },
             { "quc", "quich\u00e9" },
+            { "type.nu.gonm", "masaramgondiska siffror" },
             { "qug", "Chimborazo-h\u00f6glandskichwa" },
             { "Newa", metaValue_new },
             { "gaa", "g\u00e3" },
             { "wa", "vallonska" },
             { "gag", "gagauziska" },
             { "syr", metaValue_syr },
+            { "type.nu.gong", "gunjalagondiska siffror" },
             { "Grek", metaValue_el },
             { "gan", "gan" },
             { "kiu", "kirmanjki" },
@@ -1311,6 +1329,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "mni", "manipuri" },
             { "Latn", "latinska" },
             { "Latg", "gaeliskt latin" },
+            { "Nand", "nandinagari" },
             { "type.nu.hans", "f\u00f6renklat kinesiskt stavade tal" },
             { "type.nu.hant", "traditionellt kinesiskt stavade tal" },
             { "xh", "xhosa" },
