@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -84,21 +84,27 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "Tagb", "Ch\u1eef Tagbanwa" },
             { "Zsye", "Bi\u1ec3u t\u01b0\u1ee3ng" },
             { "%%NJIVA", "Ph\u01b0\u01a1ng ng\u1eef Gniva/Njiva" },
+            { "ccp", "Ti\u1ebfng Chakma" },
             { "egy", "Ti\u1ebfng Ai C\u1eadp c\u1ed5" },
             { "raj", "Ti\u1ebfng Rajasthani" },
             { "Phag", "Ch\u1eef Phags-pa" },
             { "tem", "Ti\u1ebfng Timne" },
+            { "Medf", "Medf" },
+            { "type.nu.sind", "Ch\u1eef s\u1ed1 Sind" },
             { "teo", "Ti\u1ebfng Teso" },
             { "rap", "Ti\u1ebfng Rapanui" },
             { "ter", "Ti\u1ebfng Tereno" },
             { "AC", "\u0110\u1ea3o Ascension" },
             { "rar", "Ti\u1ebfng Rarotongan" },
             { "tet", "Ti\u1ebfng Tetum" },
+            { "%%BARLA", "BARLA" },
+            { "type.nu.sinh", "Ch\u1eef s\u1ed1 Sinh" },
             { "AD", "Andorra" },
             { "AE", "C\u00e1c Ti\u1ec3u V\u01b0\u01a1ng qu\u1ed1c \u1ea2 R\u1eadp Th\u1ed1ng nh\u1ea5t" },
             { "nl_BE", "Ti\u1ebfng Flemish" },
             { "AF", "Afghanistan" },
             { "AG", "Antigua v\u00e0 Barbuda" },
+            { "type.nu.mroo", "Ch\u1eef s\u1ed1 Mroo" },
             { "type.ca.ethiopic", "L\u1ecbch Ethiopia" },
             { "glk", "Ti\u1ebfng Gilaki" },
             { "AI", "Anguilla" },
@@ -126,6 +132,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kum", "Ti\u1ebfng Kumyk" },
             { "BE", "B\u1ec9" },
             { "gmh", "Ti\u1ebfng Th\u01b0\u1ee3ng Gi\u00e9c-man Trung c\u1ed5" },
+            { "Sogo", "Sogo" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgaria" },
             { "BH", "Bahrain" },
@@ -148,6 +155,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "BZ", "Belize" },
             { "Visp", "Ti\u1ebfng n\u00f3i Nh\u00ecn th\u1ea5y \u0111\u01b0\u1ee3c" },
             { "type.ca.persian", "L\u1ecbch Ba T\u01b0" },
+            { "%%CREISS", "CREISS" },
             { "type.nu.hebr", "Ch\u1eef s\u1ed1 Do Th\u00e1i" },
             { "CA", "Canada" },
             { "CC", "Qu\u1ea7n \u0111\u1ea3o Cocos (Keeling)" },
@@ -173,7 +181,10 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.bali", "Ch\u1eef s\u1ed1 Bali" },
             { "CZ", "S\u00e9c" },
             { "eka", "Ti\u1ebfng Ekajuk" },
+            { "Ahom", "Ahom" },
+            { "Pauc", "Pauc" },
             { "%%RIGIK", "Ti\u1ebfng Volap\u00fck C\u1ed5 \u0111i\u1ec3n" },
+            { "Sogd", "Sogd" },
             { "DE", "\u0110\u1ee9c" },
             { "goh", "Ti\u1ebfng Th\u01b0\u1ee3ng Gi\u00e9c-man c\u1ed5" },
             { "ace", "Ti\u1ebfng Achinese" },
@@ -217,6 +228,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "chm", "Ti\u1ebfng Mari" },
             { "chp", "Ti\u1ebfng Chipewyan" },
             { "cho", "Ti\u1ebfng Choctaw" },
+            { "type.nu.mathbold", "Ch\u1eef s\u1ed1 Mathbold" },
             { "chr", "Ti\u1ebfng Cherokee" },
             { "ER", "Eritrea" },
             { "ES", "T\u00e2y Ban Nha" },
@@ -238,6 +250,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "Taml", "Ch\u1eef Tamil" },
             { "FR", "Ph\u00e1p" },
             { "Kpel", "Ch\u1eef Kpelle" },
+            { "%%SIMPLE", "SIMPLE" },
             { "tkl", "Ti\u1ebfng Tokelau" },
             { "grb", "Ti\u1ebfng Grebo" },
             { "root", "Ti\u1ebfng Root" },
@@ -266,6 +279,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "GS", "Nam Georgia & Qu\u1ea7n \u0111\u1ea3o Nam Sandwich" },
             { "GT", "Guatemala" },
             { "GU", "Guam" },
+            { "type.nu.mathmono", "Ch\u1eef s\u1ed1 Mathmono" },
             { "GW", "Guinea-Bissau" },
             { "tli", "Ti\u1ebfng Tlingit" },
             { "tlh", "Ti\u1ebfng Klingon" },
@@ -274,6 +288,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "ckb", "Ti\u1ebfng Kurd Mi\u1ec1n Trung" },
             { "zxx", "Kh\u00f4ng c\u00f3 n\u1ed9i dung ng\u00f4n ng\u1eef" },
             { "Jurc", "Ch\u1eef Jurchen" },
+            { "%%VIVARAUP", "VIVARAUP" },
             { "HK", "H\u1ed3ng K\u00f4ng, Trung Qu\u1ed1c" },
             { "Vaii", "Ch\u1eef Vai" },
             { "HM", "Qu\u1ea7n \u0111\u1ea3o Heard v\u00e0 McDonald" },
@@ -289,6 +304,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "nan", "Ti\u1ebfng M\u00e2n Nam" },
             { "ID", "Indonesia" },
             { "peo", "Ti\u1ebfng Ba T\u01b0 c\u1ed5" },
+            { "Adlm", "Adlm" },
             { "type.nu.kali", "Ch\u1eef s\u1ed1 Kayah Li" },
             { "IE", "Ireland" },
             { "nap", "Ti\u1ebfng Napoli" },
@@ -302,7 +318,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "IM", "\u0110\u1ea3o Man" },
             { "IN", "\u1ea4n \u0110\u1ed9" },
             { "type.co.eor", "Quy t\u1eafc s\u1eafp x\u1ebfp Ch\u00e2u \u00c2u" },
-            { "IO", "L\u00e3nh th\u1ed5 \u1ea4n \u0111\u1ed9 d\u01b0\u01a1ng thu\u1ed9c Anh" },
+            { "IO", "L\u00e3nh th\u1ed5 \u1ea4n \u0110\u1ed9 D\u01b0\u01a1ng thu\u1ed9c Anh" },
             { "IQ", "Iraq" },
             { "IR", "Iran" },
             { "IS", "Iceland" },
@@ -311,20 +327,24 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.thai", "Ch\u1eef s\u1ed1 Th\u00e1i" },
             { "%%POSIX", "M\u00e1y t\u00ednh" },
             { "type.nu.beng", "Ch\u1eef s\u1ed1 Bangladesh" },
+            { "type.nu.cyrl", "S\u1ed1 Kirin" },
             { "JE", "Jersey" },
             { "type.ca.islamic", "L\u1ecbch H\u1ed3i Gi\u00e1o" },
             { "JM", "Jamaica" },
             { "Beng", "Ch\u1eef Bangladesh" },
+            { "%%EKAVSK", "EKAVSK" },
             { "JO", "Jordan" },
             { "gur", "Ti\u1ebfng Frafra" },
             { "JP", "Nh\u1eadt B\u1ea3n" },
             { "%%1606NICT", "Ti\u1ebfng Ph\u00e1p t\u1eeb Cu\u1ed1i th\u1eddi Trung c\u1ed5 \u0111\u1ebfn 1606" },
             { "ain", "Ti\u1ebfng Ainu" },
+            { "%%KOCIEWIE", "KOCIEWIE" },
             { "Mend", "Ch\u1eef Mende" },
             { "guz", "Ti\u1ebfng Gusii" },
             { "tog", "Ti\u1ebfng Nyasa Tonga" },
             { "type.nu.knda", "Ch\u1eef s\u1ed1 Kannada" },
             { "Kali", "Ch\u1eef Kayah Li" },
+            { "Sidd", "Sidd" },
             { "de_CH", "Ti\u1ebfng Th\u01b0\u1ee3ng Gi\u00e9c-man (Th\u1ee5y S\u0129)" },
             { "type.co.phonetic", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo ng\u1eef \u00e2m" },
             { "izh", "Ti\u1ebfng Ingria" },
@@ -352,12 +372,12 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "phn", "Ti\u1ebfng Phoenicia" },
             { "Cyrs", "Ch\u1eef Kirin Slav\u01a1 Nh\u00e0 th\u1edd c\u1ed5" },
             { "gwi", "Ti\u1ebfng Gwich\u02bcin" },
-            { "%%LUNA1918", "LUNA1918" },
             { "nds", "Ti\u1ebfng H\u1ea1 Gi\u00e9c-man" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
             { "akk", "Ti\u1ebfng Akkadia" },
             { "cop", "Ti\u1ebfng Coptic" },
+            { "Hmnp", "Hmnp" },
             { "LR", "Liberia" },
             { "esu", "Ti\u1ebfng Yupik Mi\u1ec1n Trung" },
             { "LS", "Lesotho" },
@@ -371,8 +391,8 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "lad", "Ti\u1ebfng Ladino" },
             { "vun", "Ti\u1ebfng Vunjo" },
             { "akz", "Ti\u1ebfng Alabama" },
-            { "%%LAUKIKA", "LAUKIKA" },
             { "lah", "Ti\u1ebfng Lahnda" },
+            { "Mahj", "Mahj" },
             { "lag", "Ti\u1ebfng Langi" },
             { "Thaa", "Ch\u1eef Thaana" },
             { "MA", "Ma-r\u1ed1c" },
@@ -387,7 +407,8 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "ale", "Ti\u1ebfng Aleut" },
             { "Thai", "Ch\u1eef Th\u00e1i" },
             { "type.nu.vaii", "Ch\u1eef s\u1ed1 Vai" },
-            { "MK", "Macedonia" },
+            { "MK", "B\u1eafc Macedonia" },
+            { "type.nu.mathdbl", "Ch\u1eef s\u1ed1 Mathdbl" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Mi\u1ebfn \u0110i\u1ec7n)" },
             { "MN", "M\u00f4ng C\u1ed5" },
@@ -400,7 +421,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "MS", "Montserrat" },
             { "MT", "Malta" },
             { "cps", "Ti\u1ebfng Capiznon" },
-            { "type.m0.ungegn", "UNGEGN" },
+            { "type.m0.ungegn", "Chuy\u1ec3n t\u1ef1 UN GEGN" },
             { "MU", "Mauritius" },
             { "alt", "Ti\u1ebfng Altai Mi\u1ec1n Nam" },
             { "MV", "Maldives" },
@@ -411,6 +432,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "MZ", "Mozambique" },
             { "Phli", "Ch\u1eef Pahlavi V\u0103n bia" },
             { "NA", "Namibia" },
+            { "%%ARANES", "ARANES" },
             { "202", "Ch\u00e2u Phi h\u1ea1 Sahara" },
             { "type.ca.hebrew", "L\u1ecbch Do Th\u00e1i" },
             { "type.co.dictionary", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo t\u1eeb \u0111i\u1ec3n" },
@@ -434,15 +456,18 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "tsi", "Ti\u1ebfng Tsimshian" },
             { "NZ", "New Zealand" },
             { "Merc", "Ch\u1eef Meroitic N\u00e9t th\u1ea3o" },
+            { "%%COLB1945", "COLB1945" },
             { "rom", "Ti\u1ebfng Romany" },
             { "Mero", "Ch\u1eef Meroitic" },
             { "crh", "Ti\u1ebfng Th\u1ed5 Nh\u0129 K\u1ef3 Crimean" },
             { "ang", "Ti\u1ebfng Anh c\u1ed5" },
+            { "%%GRMISTR", "GRMISTR" },
             { "OM", "Oman" },
-            { "%%PETR1708", "PETR1708" },
             { "anp", "Ti\u1ebfng Angika" },
             { "crs", "Ti\u1ebfng Ph\u00e1p Seselwa Creole" },
+            { "type.nu.hmnp", "Ch\u1eef s\u1ed1 Hmnp" },
             { "Xpeo", "Ch\u1eef Ba T\u01b0 c\u1ed5" },
+            { "type.nu.hmng", "Ch\u1eef s\u1ed1 Hmng" },
             { "PA", "Panama" },
             { "type.ca.islamic-civil", "L\u1ecbch Islamic-Civil" },
             { "csb", "Ti\u1ebfng Kashubia" },
@@ -452,6 +477,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "PG", "Papua New Guinea" },
             { "PH", "Philippines" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "NICARD" },
             { "PL", "Ba Lan" },
             { "ewo", "Ti\u1ebfng Ewondo" },
             { "PM", "Saint Pierre v\u00e0 Miquelon" },
@@ -473,10 +499,13 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "QO", "V\u00f9ng xa x\u00f4i thu\u1ed9c Ch\u00e2u \u0110\u1ea1i D\u01b0\u01a1ng" },
             { "ext", "Ti\u1ebfng Extremadura" },
             { "lez", "Ti\u1ebfng Lezghian" },
+            { "type.nu.ahom", "Ch\u1eef s\u1ed1 Ahom" },
             { "%%FONUPA", "Ng\u1eef \u00e2m h\u1ecdc UPA" },
             { "type.nu.takr", "Ch\u1eef s\u1ed1 Takri" },
             { "tvl", "Ti\u1ebfng Tuvalu" },
             { "Tavt", "Ch\u1eef Th\u00e1i Vi\u1ec7t" },
+            { "%%SOTAV", "SOTAV" },
+            { "Maka", "Maka" },
             { "001", "Th\u1ebf gi\u1edbi" },
             { "002", "Ch\u00e2u Phi" },
             { "njo", "Ti\u1ebfng Ao Naga" },
@@ -486,7 +515,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "jbo", "Ti\u1ebfng Lojban" },
             { "Rjng", "Ch\u1eef Rejang" },
             { "009", "Ch\u00e2u \u0110\u1ea1i D\u01b0\u01a1ng" },
-            { "%%SURSILV", "SURSILV" },
+            { "Elym", "Elym" },
             { "RO", "Romania" },
             { "RS", "Serbia" },
             { "Mroo", "Ch\u1eef Mro" },
@@ -516,6 +545,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.lb.strict", "Ki\u1ec3u xu\u1ed1ng d\u00f2ng h\u1eb9p" },
             { "017", "Trung Phi" },
             { "SI", "Slovenia" },
+            { "type.nu.mymrtlng", "Ch\u1eef s\u1ed1 Mymrtlng" },
             { "018", "Mi\u1ec1n Nam Ch\u00e2u Phi" },
             { "SJ", "Svalbard v\u00e0 Jan Mayen" },
             { "019", "Ch\u00e2u M\u1ef9" },
@@ -550,6 +580,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "TC", "Qu\u1ea7n \u0111\u1ea3o Turks v\u00e0 Caicos" },
             { "yav", "Ti\u1ebfng Yangben" },
             { "TD", "Chad" },
+            { "Qaag", "Qaag" },
             { "TF", "L\u00e3nh th\u1ed5 ph\u00eda Nam Thu\u1ed9c Ph\u00e1p" },
             { "ase", "Ng\u00f4n ng\u1eef K\u00fd hi\u1ec7u M\u1ef9" },
             { "TG", "Togo" },
@@ -593,6 +624,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "US", "Hoa K\u1ef3" },
             { "haw", "Ti\u1ebfng Hawaii" },
             { "%%1959ACAD", "H\u00e0n l\u00e2m" },
+            { "%%IVANCHOV", "IVANCHOV" },
             { "type.co.gb2312han", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp theo ti\u1ebfng Trung gi\u1ea3n th\u1ec3 - GB2312" },
             { "UY", "Uruguay" },
             { "prg", "Ti\u1ebfng Prussia" },
@@ -603,11 +635,15 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "VA", "Th\u00e0nh Vatican" },
             { "pro", "Ti\u1ebfng Proven\u00e7al c\u1ed5" },
             { "VC", "St. Vincent v\u00e0 Grenadines" },
+            { "%%HSISTEMO", "HSISTEMO" },
             { "VE", "Venezuela" },
             { "VG", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c Anh" },
             { "VI", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c M\u1ef9" },
+            { "%%LEMOSIN", "LEMOSIN" },
+            { "Soyo", "Soyo" },
             { "VN", "Vi\u1ec7t Nam" },
             { "VU", "Vanuatu" },
+            { "Marc", "Marc" },
             { "nog", "Ti\u1ebfng Nogai" },
             { "rwk", "Ti\u1ebfng Rwa" },
             { "non", "Ti\u1ebfng Na Uy c\u1ed5" },
@@ -628,7 +664,9 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.mtei", "Ch\u1eef s\u1ed1 Meetei Mayek" },
             { "wal", "Ti\u1ebfng Walamo" },
             { "was", "Ti\u1ebfng Washo" },
+            { "XA", "XA" },
             { "war", "Ti\u1ebfng Waray" },
+            { "XB", "XB" },
             { "awa", "Ti\u1ebfng Awadhi" },
             { "061", "Polynesia" },
             { "%%KSCOR", "Ph\u00e9p ch\u00ednh t\u1ea3 Chu\u1ea9n" },
@@ -643,13 +681,15 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "YE", "Yemen" },
             { "nqo", "Ti\u1ebfng N\u2019Ko" },
             { "type.co.standard", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp chu\u1ea9n" },
+            { "Zanb", "Zanb" },
             { "fan", "Ti\u1ebfng Fang" },
+            { "%%BALANKA", "BALANKA" },
             { "%%ROZAJ", "Ti\u1ebfng Resian" },
-            { "%%SUTSILV", "SUTSILV" },
             { "fat", "Ti\u1ebfng Fanti" },
             { "Sgnw", "Ch\u1eef vi\u1ebft K\u00fd hi\u1ec7u" },
             { "YT", "Mayotte" },
             { "type.nu.cham", "Ch\u1eef s\u1ed1 Ch\u0103m" },
+            { "%%NEWFOUND", "NEWFOUND" },
             { "ZA", "Nam Phi" },
             { "type.nu.sund", "Ch\u1eef s\u1ed1 Sudan" },
             { "type.lb.loose", "Ki\u1ec3u xu\u1ed1ng d\u00f2ng tho\u00e1ng" },
@@ -669,7 +709,10 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.telu", "Ch\u1eef s\u1ed1 Telugu" },
             { "lou", "Ti\u1ebfng Creole Louisiana" },
             { "loz", "Ti\u1ebfng Lozi" },
+            { "%%FONKIRSH", "FONKIRSH" },
             { "Nkgb", "Ch\u1eef Naxi Geba" },
+            { "%%ASANTE", "ASANTE" },
+            { "%%AUVERN", "AUVERN" },
             { "jmc", "Ti\u1ebfng Machame" },
             { "hif", "Ti\u1ebfng Fiji Hindi" },
             { "type.nu.hansfin", "Ch\u1eef s\u1ed1 d\u00f9ng trong t\u00e0i ch\u00ednh c\u1ee7a ti\u1ebfng Trung gi\u1ea3n th\u1ec3" },
@@ -683,10 +726,12 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "dav", "Ti\u1ebfng Taita" },
             { "Maya", "Ch\u1eef t\u01b0\u1ee3ng h\u00ecnh Maya" },
             { "lrc", "Ti\u1ebfng B\u1eafc Luri" },
+            { "type.co.emoji", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp bi\u1ec3u t\u01b0\u1ee3ng" },
             { "Copt", "Ch\u1eef Coptic" },
             { "nwc", "Ti\u1ebfng Newari c\u1ed5" },
             { "udm", "Ti\u1ebfng Udmurt" },
             { "Khmr", "Ch\u1eef Kh\u01a1-me" },
+            { "%%FONNAPA", "FONNAPA" },
             { "type.ca.islamic-rgsa", "L\u1ecbch H\u1ed3i Gi\u00e1o - \u1ea2 R\u1eadp X\u00ea-\u00fat" },
             { "Limb", "Ch\u1eef Limbu" },
             { "sad", "Ti\u1ebfng Sandawe" },
@@ -694,6 +739,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sah", "Ti\u1ebfng Sakha" },
             { "type.nu.shrd", "Ch\u1eef s\u1ed1 Sharada" },
             { "sam", "Ti\u1ebfng Samaritan Aramaic" },
+            { "Aghb", "Aghb" },
             { "%%SCOUSE", "Ph\u01b0\u01a1ng ng\u1eef Liverpool" },
             { "saq", "Ti\u1ebfng Samburu" },
             { "sas", "Ti\u1ebfng Sasak" },
@@ -706,10 +752,11 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "Guru", "Ch\u1eef Gurmukhi" },
             { "%%ALUKU", "Ph\u01b0\u01a1ng ng\u1eef Aluku" },
             { "lua", "Ti\u1ebfng Luba-Lulua" },
-            { "%%BISCAYAN", "BISCAYAN" },
+            { "type.nu.tirh", "Ch\u1eef s\u1ed1 Tirh" },
             { "type.d0.fwidth", "\u0110\u1ed9 r\u1ed9ng t\u1ed1i \u0111a" },
             { "sbp", "Ti\u1ebfng Sangu" },
             { "lui", "Ti\u1ebfng Luiseno" },
+            { "%%GRITAL", "GRITAL" },
             { "nyn", "Ti\u1ebfng Nyankole" },
             { "nym", "Ti\u1ebfng Nyamwezi" },
             { "lun", "Ti\u1ebfng Lunda" },
@@ -723,10 +770,12 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "den", "Ti\u1ebfng Slave" },
             { "ban", "Ti\u1ebfng Bali" },
             { "uga", "Ti\u1ebfng Ugaritic" },
+            { "type.nu.wara", "Ch\u1eef s\u1ed1 Wara" },
             { "luy", "Ti\u1ebfng Luyia" },
             { "bar", "Ti\u1ebfng Bavaria" },
             { "bas", "Ti\u1ebfng Basaa" },
             { "bax", "Ti\u1ebfng Bamun" },
+            { "%%ABL1943", "ABL1943" },
             { "jrb", "Ti\u1ebfng Judeo-\u1ea2 R\u1eadp" },
             { "es_ES", "Ti\u1ebfng T\u00e2y Ban Nha (Ch\u00e2u \u00c2u)" },
             { "nzi", "Ti\u1ebfng Nzima" },
@@ -754,8 +803,11 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sdh", "Ti\u1ebfng Kurd Mi\u1ec1n Nam" },
             { "ay", "Ti\u1ebfng Aymara" },
             { "az", "Ti\u1ebfng Azerbaijan" },
+            { "Rohg", "Rohg" },
             { "Khoj", "Ch\u1eef Khojki" },
+            { "%%CISAUP", "CISAUP" },
             { "%%OSOJS", "Ph\u01b0\u01a1ng ng\u1eef Oseacco/Osojane" },
+            { "%%UNIFON", "UNIFON" },
             { "ba", "Ti\u1ebfng Bashkir" },
             { "type.co.unihan", "Tr\u00ecnh t\u1ef1 s\u1eafp x\u1ebfp theo b\u1ed9-n\u00e9t" },
             { "be", "Ti\u1ebfng Belarus" },
@@ -768,6 +820,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "dgr", "Ti\u1ebfng Dogrib" },
             { "br", "Ti\u1ebfng Breton" },
             { "bs", "Ti\u1ebfng Bosnia" },
+            { "Bhks", "Bhks" },
             { "see", "Ti\u1ebfng Seneca" },
             { "Mymr", "Ch\u1eef Myanmar" },
             { "type.nu.laoo", "Ch\u1eef s\u1ed1 L\u00e0o" },
@@ -827,7 +880,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "shi", "Ti\u1ebfng Tachelhit" },
             { "hsb", "Ti\u1ebfng Th\u01b0\u1ee3ng Sorbia" },
             { "Hani", "Ch\u1eef H\u00e1n" },
-            { "%%ULSTER", "ULSTER" },
             { "shn", "Ti\u1ebfng Shan" },
             { "Hano", "Ch\u1eef Hanunoo" },
             { "fa", "Ti\u1ebfng Ba T\u01b0" },
@@ -843,14 +895,18 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "bgn", "Ti\u1ebfng T\u00e2y Balochi" },
             { "yue", "Ti\u1ebfng Qu\u1ea3ng \u0110\u00f4ng" },
             { "fo", "Ti\u1ebfng Faroe" },
-            { "type.m0.bgn", "BGN" },
+            { "type.m0.bgn", "Chuy\u1ec3n t\u1ef1 US BGN" },
             { "umb", "Ti\u1ebfng Umbundu" },
             { "fr", "Ti\u1ebfng Ph\u00e1p" },
+            { "%%AKUAPEM", "AKUAPEM" },
             { "sid", "Ti\u1ebfng Sidamo" },
             { "fy", "Ti\u1ebfng Frisia" },
             { "ga", "Ti\u1ebfng Ireland" },
+            { "Wcho", "Wcho" },
             { "gd", "Ti\u1ebfng Gael Scotland" },
+            { "Gong", "Gong" },
             { "gl", "Ti\u1ebfng Galician" },
+            { "Gonm", "Gonm" },
             { "gn", "Ti\u1ebfng Guarani" },
             { "bho", "Ti\u1ebfng Bhojpuri" },
             { "und", "Ng\u00f4n ng\u1eef kh\u00f4ng x\u00e1c \u0111\u1ecbnh" },
@@ -878,10 +934,11 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "id", "Ti\u1ebfng Indonesia" },
             { "type.nu.tibt", "Ch\u1eef s\u1ed1 T\u00e2y T\u1ea1ng" },
             { "ie", "Ti\u1ebfng Interlingue" },
+            { "%%GASCON", "GASCON" },
             { "ig", "Ti\u1ebfng Igbo" },
             { "ii", "Ti\u1ebfng Di T\u1ee9 Xuy\u00ean" },
             { "frm", "Ti\u1ebfng Ph\u00e1p Trung c\u1ed5" },
-            { "%%RUMGR", "RUMGR" },
+            { "%%AO1990", "AO1990" },
             { "ik", "Ti\u1ebfng Inupiaq" },
             { "fro", "Ti\u1ebfng Ph\u00e1p c\u1ed5" },
             { "frp", "Ti\u1ebfng Arpitan" },
@@ -892,7 +949,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "is", "Ti\u1ebfng Iceland" },
             { "it", "Ti\u1ebfng Italy" },
             { "iu", "Ti\u1ebfng Inuktitut" },
-            { "%%HOGNORSK", "HOGNORSK" },
+            { "%%CORNU", "CORNU" },
             { "ja", "Ti\u1ebfng Nh\u1eadt" },
             { "Mlym", "Ch\u1eef Malayalam" },
             { "Sarb", "Ch\u1eef Nam \u1ea2 R\u1eadp c\u1ed5" },
@@ -903,7 +960,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sma", "Ti\u1ebfng Sami Mi\u1ec1n Nam" },
             { "jv", "Ti\u1ebfng Java" },
             { "Shaw", "Ch\u1eef Shavian" },
-            { "%%BAUDDHA", "BAUDDHA" },
             { "mad", "Ti\u1ebfng Madura" },
             { "smj", "Ti\u1ebfng Lule Sami" },
             { "mag", "Ti\u1ebfng Magahi" },
@@ -936,7 +992,9 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kw", "Ti\u1ebfng Cornwall" },
             { "ky", "Ti\u1ebfng Kyrgyz" },
             { "snk", "Ti\u1ebfng Soninke" },
+            { "Mult", "Mult" },
             { "la", "Ti\u1ebfng La-tinh" },
+            { "Hatr", "Hatr" },
             { "lb", "Ti\u1ebfng Luxembourg" },
             { "type.nu.mlym", "Ch\u1eef s\u1ed1 Malayalam" },
             { "lg", "Ti\u1ebfng Ganda" },
@@ -979,7 +1037,10 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "nl", "Ti\u1ebfng H\u00e0 Lan" },
             { "nn", "Ti\u1ebfng Na Uy (Nynorsk)" },
             { "no", "Ti\u1ebfng Na Uy" },
+            { "%%PROVENC", "PROVENC" },
             { "nr", "Ti\u1ebfng Ndebele Mi\u1ec1n Nam" },
+            { "type.nu.modi", "Ch\u1eef s\u1ed1 Modi" },
+            { "Osge", "Osge" },
             { "nv", "Ti\u1ebfng Navajo" },
             { "kaa", "Ti\u1ebfng Kara-Kalpak" },
             { "ny", "Ti\u1ebfng Nyanja" },
@@ -998,6 +1059,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kaw", "Ti\u1ebfng Kawi" },
             { "dtp", "Ti\u1ebfng Dusun Mi\u1ec1n Trung" },
             { "or", "Ti\u1ebfng Odia" },
+            { "Modi", "Modi" },
             { "os", "Ti\u1ebfng Ossetic" },
             { "%%ALALC97", "La M\u00e3 h\u00f3a ALA-LC, \u1ea5n b\u1ea3n n\u0103m 1997" },
             { "bpy", "Ti\u1ebfng Bishnupriya" },
@@ -1015,7 +1077,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "dum", "Ti\u1ebfng H\u00e0 Lan Trung c\u1ed5" },
             { "type.nu.saur", "Ch\u1eef s\u1ed1 Saurashtra" },
             { "type.ca.dangi", "L\u1ecbch Dangi" },
-            { "%%VALLADER", "VALLADER" },
             { "ps", "Ti\u1ebfng Pashto" },
             { "pt", "Ti\u1ebfng B\u1ed3 \u0110\u00e0o Nha" },
             { "mga", "Ti\u1ebfng Ai-len Trung c\u1ed5" },
@@ -1027,9 +1088,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "type.nu.nkoo", "Ch\u1eef s\u1ed1 N\u2019Ko" },
             { "bra", "Ti\u1ebfng Braj" },
             { "key.ca", "L\u1ecbch" },
-            { "%%JAUER", "JAUER" },
             { "Laoo", "Ch\u1eef L\u00e0o" },
-            { "%%SURMIRAN", "SURMIRAN" },
             { "mgo", "Ti\u1ebfng Meta\u2019" },
             { "type.hc.h23", "H\u1ec7 th\u1ed1ng 24 gi\u1edd (0\u201323)" },
             { "type.hc.h24", "H\u1ec7 th\u1ed1ng 24 gi\u1edd (1\u201324)" },
@@ -1041,9 +1100,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "brx", "Ti\u1ebfng Bodo" },
             { "Lana", "Ch\u1eef Lanna" },
             { "kde", "Ti\u1ebfng Makonde" },
-            { "%%VAIDIKA", "VAIDIKA" },
             { "Ethi", "Ch\u1eef Ethiopia" },
-            { "%%JYUTPING", "JYUTPING" },
             { "type.hc.h12", "H\u1ec7 th\u1ed1ng 12 gi\u1edd (1\u201312)" },
             { "type.hc.h11", "H\u1ec7 th\u1ed1ng 12 gi\u1edd (0\u201311)" },
             { "rm", "Ti\u1ebfng Romansh" },
@@ -1076,6 +1133,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "sl", "Ti\u1ebfng Slovenia" },
             { "Gran", "Ch\u1eef Grantha" },
             { "sm", "Ti\u1ebfng Samoa" },
+            { "%%BASICENG", "BASICENG" },
             { "sn", "Ti\u1ebfng Shona" },
             { "so", "Ti\u1ebfng Somali" },
             { "type.nu.arab", "Ch\u1eef s\u1ed1 \u1ea2 R\u1eadp - \u1ea4n \u0110\u1ed9" },
@@ -1089,6 +1147,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "%%NEDIS", "Ph\u01b0\u01a1ng ng\u1eef Natisone" },
             { "sv", "Ti\u1ebfng Th\u1ee5y \u0110i\u1ec3n" },
             { "sw", "Ti\u1ebfng Swahili" },
+            { "type.nu.wcho", "Ch\u1eef s\u1ed1 Wancho" },
             { "type.nu.hantfin", "Ch\u1eef s\u1ed1 d\u00f9ng trong t\u00e0i ch\u00ednh c\u1ee7a ti\u1ebfng Trung ph\u1ed3n th\u1ec3" },
             { "ibb", "Ti\u1ebfng Ibibio" },
             { "iba", "Ti\u1ebfng Iban" },
@@ -1100,6 +1159,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "145", "T\u00e2y \u00c1" },
             { "tg", "Ti\u1ebfng Tajik" },
             { "th", "Ti\u1ebfng Th\u00e1i" },
+            { "%%SPANGLIS", "SPANGLIS" },
             { "ti", "Ti\u1ebfng Tigrinya" },
             { "bug", "Ti\u1ebfng Bugin" },
             { "kfo", "Ti\u1ebfng Koro" },
@@ -1115,12 +1175,15 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "swb", "Ti\u1ebfng C\u00f4mo" },
             { "Cakm", "Ch\u1eef Chakma" },
             { "tt", "Ti\u1ebfng Tatar" },
+            { "%%XSISTEMO", "XSISTEMO" },
             { "dyu", "Ti\u1ebfng Dyula" },
             { "tw", "Ti\u1ebfng Twi" },
             { "ty", "Ti\u1ebfng Tahiti" },
             { "%%BISKE", "Ph\u01b0\u01a1ng ng\u1eef San Giorgio/Bila" },
             { "150", "Ch\u00e2u \u00c2u" },
             { "151", "\u0110\u00f4ng \u00c2u" },
+            { "type.nu.rohg", "Ch\u1eef s\u1ed1 Rohg" },
+            { "type.nu.mathsanb", "Ch\u1eef s\u1ed1 Mathsanb" },
             { "154", "B\u1eafc \u00c2u" },
             { "dzg", "Ti\u1ebfng Dazaga" },
             { "155", "T\u00e2y \u00c2u" },
@@ -1149,13 +1212,17 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "%%TARASK", "Ph\u00e9p ch\u00ednh t\u1ea3 Taraskievica" },
             { "vo", "Ti\u1ebfng Volap\u00fck" },
             { "syc", "Ti\u1ebfng Syriac c\u1ed5" },
+            { "type.nu.mathsans", "Ch\u1eef s\u1ed1 Mathsans" },
             { "Osma", "Ch\u1eef Osmanya" },
             { "quc", "Ti\u1ebfng K\u02bciche\u02bc" },
+            { "type.nu.gonm", "Ch\u1eef s\u1ed1 Gonm" },
             { "qug", "Ti\u1ebfng Quechua \u1edf Cao nguy\u00ean Chimborazo" },
+            { "Newa", "Newa" },
             { "gaa", "Ti\u1ebfng Ga" },
             { "wa", "Ti\u1ebfng Walloon" },
             { "gag", "Ti\u1ebfng Gagauz" },
             { "syr", "Ti\u1ebfng Syriac" },
+            { "type.nu.gong", "Ch\u1eef s\u1ed1 Gong" },
             { "Grek", "Ch\u1eef Hy L\u1ea1p" },
             { "gan", "Ti\u1ebfng C\u00e1m" },
             { "Lydi", "Ch\u1eef Lydia" },
@@ -1164,7 +1231,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "zgh", "Ti\u1ebfng Tamazight Chu\u1ea9n c\u1ee7a Ma-r\u1ed1c" },
             { "ar_001", "Ti\u1ebfng \u1ea2 R\u1eadp Hi\u1ec7n \u0111\u1ea1i" },
             { "Cans", "\u00c2m ti\u1ebft Th\u1ed5 d\u00e2n Canada H\u1ee3p nh\u1ea5t" },
-            { "%%FONXSAMP", "FONXSAMP" },
             { "gay", "Ti\u1ebfng Gayo" },
             { "Mong", "Ch\u1eef M\u00f4ng C\u1ed5" },
             { "mnc", "Ti\u1ebfng M\u00e3n Ch\u00e2u" },
@@ -1174,11 +1240,13 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "mni", "Ti\u1ebfng Manipuri" },
             { "Latn", "Ch\u1eef La tinh" },
             { "Latg", "Ch\u1eef La-tinh Xc\u1ed1t-len" },
+            { "Nand", "Nand" },
             { "type.nu.hans", "Ch\u1eef s\u1ed1 c\u1ee7a ti\u1ebfng Trung gi\u1ea3n th\u1ec3" },
             { "type.nu.hant", "Ch\u1eef s\u1ed1 ti\u1ebfng Trung ph\u1ed3n th\u1ec3" },
             { "xh", "Ti\u1ebfng Xhosa" },
             { "type.nu.romanlow", "Ch\u1eef s\u1ed1 La M\u00e3 vi\u1ebft th\u01b0\u1eddng" },
             { "byn", "Ti\u1ebfng Blin" },
+            { "Dogr", "Dogr" },
             { "%%PAMAKA", "Ph\u01b0\u01a1ng ng\u1eef Pamaka" },
             { "Lyci", "Ch\u1eef Lycia" },
             { "osa", "Ti\u1ebfng Osage" },
@@ -1210,19 +1278,20 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "%%MONOTON", "\u0110\u01a1n \u00e2m" },
             { "Geor", "Ch\u1eef Gruzia" },
             { "Shrd", "Ch\u1eef Sharada" },
+            { "%%LENGADOC", "LENGADOC" },
             { "kmb", "Ti\u1ebfng Kimbundu" },
             { "type.nu.jpanfin", "Ch\u1eef s\u1ed1 d\u00f9ng trong t\u00e0i ch\u00ednh c\u1ee7a ti\u1ebfng Nh\u1eadt" },
             { "Cham", "Ch\u1eef Ch\u0103m" },
             { "gez", "Ti\u1ebfng Geez" },
             { "Syrn", "Ch\u1eef \u0110\u00f4ng Syria" },
             { "type.nu.mymrshan", "Ch\u1eef s\u1ed1 Myanmar Shan" },
+            { "Elba", "Elba" },
             { "Narb", "Ch\u1eef B\u1eafc \u1ea2 R\u1eadp c\u1ed5" },
             { "type.nu.olck", "Ch\u1eef s\u1ed1 Ol Chiki" },
             { "type.co.reformed", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp \u0111\u00e3 s\u1eeda \u0111\u1ed5i" },
             { "Tglg", "Ch\u1eef Tagalog" },
             { "Egyd", "Ch\u1eef Ai C\u1eadp b\u00ecnh d\u00e2n" },
             { "Egyh", "Ch\u1eef Ai C\u1eadp th\u00e0y tu" },
-            { "%%ITIHASA", "ITIHASA" },
             { "Palm", "Ch\u1eef Palmyrene" },
             { "ebu", "Ti\u1ebfng Embu" },
             { "Egyp", "Ch\u1eef t\u01b0\u1ee3ng h\u00ecnh Ai C\u1eadp" },
@@ -1232,19 +1301,23 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "kok", "Ti\u1ebfng Konkani" },
             { "%%1901", "Ph\u00e9p ch\u00ednh t\u1ea3 Ti\u1ebfng \u0110\u1ee9c Truy\u1ec1n th\u1ed1ng" },
             { "kos", "Ti\u1ebfng Kosrae" },
+            { "%%PAHAWH2", "PAHAWH2" },
+            { "%%PAHAWH3", "PAHAWH3" },
+            { "%%PAHAWH4", "PAHAWH4" },
             { "type.nu.limb", "Ch\u1eef s\u1ed1 Limbu" },
             { "Sund", "Ch\u1eef Xu-\u0111\u0103ng" },
             { "kpe", "Ti\u1ebfng Kpelle" },
+            { "%%GRCLASS", "GRCLASS" },
             { "type.nu.khmr", "Ch\u1eef s\u1ed1 Kh\u01a1-me" },
             { "Tirh", "Ch\u1eef Tirhuta" },
             { "ilo", "Ti\u1ebfng Iloko" },
             { "%%VALENCIA", "Ti\u1ebfng Valencia" },
             { "Cprt", "Ch\u1ee9 S\u00edp" },
             { "%%BAKU1926", "B\u1ea3ng ch\u1eef c\u00e1i La-tinh Ti\u1ebfng Turk H\u1ee3p nh\u1ea5t" },
+            { "%%IJEKAVSK", "IJEKAVSK" },
             { "mua", "Ti\u1ebfng Mundang" },
             { "type.nu.guru", "Ch\u1eef s\u1ed1 Gurmukhi" },
             { "mul", "Nhi\u1ec1u Ng\u00f4n ng\u1eef" },
-            { "%%PUTER", "PUTER" },
             { "cad", "Ti\u1ebfng Caddo" },
             { "key.ms", "H\u1ec7 th\u1ed1ng \u0111o l\u01b0\u1eddng" },
             { "mus", "Ti\u1ebfng Creek" },
@@ -1258,6 +1331,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "krc", "Ti\u1ebfng Karachay-Balkar" },
             { "inh", "Ti\u1ebfng Ingush" },
             { "krl", "Ti\u1ebfng Karelian" },
+            { "%%OXENDICT", "OXENDICT" },
             { "efi", "Ti\u1ebfng Efik" },
             { "key.nu", metaValue_key_nu },
             { "kru", "Ti\u1ebfng Kurukh" },
