@@ -310,14 +310,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "Folklend Adalar\u0131 Vaxt\u0131",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Butan Vaxt\u0131",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia Standart Vaxt\u0131",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "Apia Vaxt\u0131",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Butan Vaxt\u0131",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru Vaxt\u0131",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbiya Standart Vaxt\u0131",
+        final String[] Australia_Eastern = new String[] {
+               "\u015e\u0259rqi Avstraliya Standart Vaxt\u0131",
                "",
-               "Kolumbiya Yay Vaxt\u0131",
+               "\u015e\u0259rqi Avstraliya Yay Vaxt\u0131",
                "",
-               "Kolumbiya Vaxt\u0131",
+               "\u015e\u0259rqi Avstraliya Vaxt\u0131",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "\u015e\u0259rqi Avstraliya Standart Vaxt\u0131",
+        final String[] Colombia = new String[] {
+               "Kolumbiya Standart Vaxt\u0131",
                "",
-               "\u015e\u0259rqi Avstraliya Yay Vaxt\u0131",
+               "Kolumbiya Yay Vaxt\u0131",
                "",
-               "\u015e\u0259rqi Avstraliya Vaxt\u0131",
+               "Kolumbiya Vaxt\u0131",
                "",
             };
         final String[] Chile = new String[] {
@@ -1038,12 +1038,12 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "\u015eimal-Q\u0259rbi Meksika Standart Vaxt\u0131",
+        final String[] Volgograd = new String[] {
+               "Volqoqrad Standart Vaxt\u0131",
                "",
-               "\u015eimal-Q\u0259rbi Meksika Yay Vaxt\u0131",
+               "Volqoqrad Yay Vaxt\u0131",
                "",
-               "\u015eimal-Q\u0259rbi Meksika Vaxt\u0131",
+               "Volqoqrad Vaxt\u0131",
                "",
             };
         final String[] Easter = new String[] {
@@ -1054,6 +1054,14 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "Pasxa Adas\u0131 Vaxt\u0131",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "\u015eimal-Q\u0259rbi Meksika Standart Vaxt\u0131",
+               "",
+               "\u015eimal-Q\u0259rbi Meksika Yay Vaxt\u0131",
+               "",
+               "\u015eimal-Q\u0259rbi Meksika Vaxt\u0131",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "D\u00fcmon-d\u2019\u00dcrvil Vaxt\u0131",
                "",
@@ -1198,14 +1206,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                "Samara vaxt\u0131",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pxenyan Vaxt\u0131",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Hindistan Vaxt\u0131",
                "",
@@ -1236,7 +1236,16 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1320,7 +1329,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nom" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vankuver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1432,12 +1440,12 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "San Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nyu York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akkra" },
             { "timezone.excity.Etc/Unknown", "Nam\u0259lum \u015e\u0259h\u0259r" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Tul" },
             { "timezone.excity.America/Grand_Turk", "Qrand Turk" },
             { "America/Yakutat", Alaska },
@@ -1499,8 +1507,17 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "M\u00fcq\u0259dd\u0259s Yelena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonqa" },
             { "timezone.excity.Europe/Luxembourg", "L\u00fcksemburq" },
             { "America/Cayman", America_Eastern },
@@ -1661,7 +1678,6 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Quz K\u00f6rf\u0259zi" },
             { "timezone.excity.America/Eirunepe", "\u0130runepe" },
             { "timezone.excity.America/Los_Angeles", "Los Anceles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Kuyaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1872,7 +1888,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1897,8 +1913,8 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Afina" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
             { "timezone.excity.America/Indiana/Knox", "Noks" },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1920,6 +1936,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Yerus\u0259lim" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riyad" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Banqui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2082,7 +2099,7 @@ public class TimeZoneNames_az extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "San Tomas" },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "\u0130stanbul" },
             { "timezone.excity.Europe/Sarajevo", "Sarayevo" },
