@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -199,11 +199,11 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Pierre_Miquelon = new String[] {
-               "Saint-Pierre-und-Miquelon-Normalzeit",
+               "St.-Pierre-und-Miquelon-Normalzeit",
                "",
-               "Saint-Pierre-und-Miquelon-Sommerzeit",
+               "St.-Pierre-und-Miquelon-Sommerzeit",
                "",
-               "Saint-Pierre-und-Miquelon-Zeit",
+               "St.-Pierre-und-Miquelon-Zeit",
                "",
             };
         final String[] Indochina = new String[] {
@@ -318,14 +318,6 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "Falklandinseln-Zeit",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bhutan-Zeit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia-Normalzeit",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "Apia-Zeit",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bhutan-Zeit",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru-Zeit",
                "",
@@ -503,7 +503,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Brunei = new String[] {
-               "Brunei-Zeit",
+               "Brunei-Darussalam-Zeit",
                "",
                "",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbianische Normalzeit",
+        final String[] Australia_Eastern = new String[] {
+               "Ostaustralische Normalzeit",
                "",
-               "Kolumbianische Sommerzeit",
+               "Ostaustralische Sommerzeit",
                "",
-               "Kolumbianische Zeit",
+               "Ostaustralische Zeit",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Ostaustralische Normalzeit",
+        final String[] Colombia = new String[] {
+               "Kolumbianische Normalzeit",
                "",
-               "Ostaustralische Sommerzeit",
+               "Kolumbianische Sommerzeit",
                "",
-               "Ostaustralische Zeit",
+               "Kolumbianische Zeit",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,14 +710,6 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "Paraguayanische Zeit",
                "",
             };
-        final String[] Casey = new String[] {
-               "Casey-Zeit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "Malaysische Zeit",
                "",
@@ -743,7 +735,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
             };
         final String[] Solomon = new String[] {
-               "Salomoninseln-Zeit",
+               "Salomonen-Zeit",
                "",
                "",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Mexiko Nordwestliche Zone-Normalzeit",
+        final String[] Volgograd = new String[] {
+               "Wolgograd-Normalzeit",
                "",
-               "Mexiko Nordwestliche Zone-Sommerzeit",
+               "Wolgograd-Sommerzeit",
                "",
-               "Mexiko Nordwestliche Zone-Zeit",
+               "Wolgograd-Zeit",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "Osterinsel-Zeit",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Mexiko Nordwestliche Zone-Normalzeit",
+               "",
+               "Mexiko Nordwestliche Zone-Sommerzeit",
+               "",
+               "Mexiko Nordwestliche Zone-Zeit",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urville-Zeit",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                "Samara-Zeit",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pj\u00f6ngjang-Zeit",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Indische Zeit",
                "",
@@ -1268,7 +1260,16 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1350,7 +1351,6 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1457,12 +1457,12 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Unbekannt" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1522,8 +1522,17 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Aqtobe", "Aktobe" },
             { "Asia/Vladivostok", Vladivostok },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/Cayman", America_Eastern },
@@ -1680,7 +1689,6 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1888,7 +1896,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1912,7 +1920,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Athen" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1934,7 +1942,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jerusalem" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riad" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2095,7 +2103,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "America/Rio_Branco", Acre },
@@ -2107,7 +2115,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Vladivostok", "Wladiwostok" },
             { "Africa/Lusaka", Africa_Central },
             { "timezone.excity.Africa/Tunis", "Tunis" },
-            { "timezone.excity.Asia/Macau", "Macao" },
+            { "timezone.excity.Asia/Macau", "Macau" },
             { "America/Argentina/La_Rioja", Argentina },
             { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
@@ -2134,7 +2142,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "Pacific/Midway", Samoa },
             { "America/Jujuy", Argentina },
             { "timezone.excity.America/Mazatlan", "Mazatlan" },
-            { "timezone.excity.Asia/Brunei", "Brunei" },
+            { "timezone.excity.Asia/Brunei", "Brunei Darussalam" },
             { "timezone.excity.Atlantic/Faeroe", "F\u00e4r\u00f6er" },
             { "timezone.excity.America/Whitehorse", "Whitehorse" },
             { "timezone.excity.Asia/Kuching", "Kuching" },
@@ -2210,7 +2218,7 @@ public class TimeZoneNames_de extends TimeZoneNamesBundle {
             { "timezone.excity.America/Iqaluit", "Iqaluit" },
             { "America/Winnipeg", America_Central },
             { "timezone.excity.Europe/Amsterdam", "Amsterdam" },
-            { "timezone.excity.Atlantic/Bermuda", "Bermudas" },
+            { "timezone.excity.Atlantic/Bermuda", "Bermuda" },
             { "timezone.excity.Pacific/Saipan", "Saipan" },
             { "timezone.excity.Indian/Cocos", "Cocos" },
             { "timezone.excity.Australia/Currie", "Currie" },
