@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -526,14 +526,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Acorski cas",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bhuta\u0144ski cas",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apiaski standardny cas",
                "",
@@ -542,6 +534,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Apiaski cas",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bhuta\u0144ski cas",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Suriname = new String[] {
                "Surinamski cas",
                "",
@@ -886,6 +886,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Nowokaledoniski cas",
                "",
             };
+        final String[] Volgograd = new String[] {
+               "Wolgogradski standardny cas",
+               "",
+               "Wolgogradski l\u011b\u015bojski cas",
+               "",
+               "Wolgogradski cas",
+               "",
+            };
         final String[] Brunei = new String[] {
                "Bruneiski cas",
                "",
@@ -902,14 +910,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Ira\u0144ski cas",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Mexiski d\u0142ujkowjacorny standardny cas",
-               "",
-               "Mexiski d\u0142ujkowjacorny l\u011b\u015bojski cas",
-               "",
-               "Mexiski d\u0142ujkowjacorny cas",
-               "",
-            };
         final String[] Easter = new String[] {
                "standardny cas Jat\u0161owneje kupy",
                "",
@@ -918,6 +918,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "cas Jat\u0161owneje kupy",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Mexiski d\u0142ujkowjacorny standardny cas",
+               "",
+               "Mexiski d\u0142ujkowjacorny l\u011b\u015bojski cas",
+               "",
+               "Mexiski d\u0142ujkowjacorny cas",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "DumontDUrville cas",
                "",
@@ -1030,12 +1038,12 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbiski standardny cas",
+        final String[] Australia_Eastern = new String[] {
+               "P\u00f3dzajt\u0161noawstralski standardny cas",
                "",
-               "Kolumbiski l\u011b\u015bojski cas",
+               "P\u00f3dzajt\u0161noawstralski l\u011b\u015bojski cas",
                "",
-               "Kolumbiski cas",
+               "P\u00f3dzajt\u0161noawstralski cas",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -1046,12 +1054,12 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "P\u00f3dzajt\u0161noawstralski standardny cas",
+        final String[] Colombia = new String[] {
+               "Kolumbiski standardny cas",
                "",
-               "P\u00f3dzajt\u0161noawstralski l\u011b\u015bojski cas",
+               "Kolumbiski l\u011b\u015bojski cas",
                "",
-               "P\u00f3dzajt\u0161noawstralski cas",
+               "Kolumbiski cas",
                "",
             };
         final String[] Chile = new String[] {
@@ -1220,7 +1228,16 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1324,7 +1341,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Europe/Malta", Europe_Central },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.Asia/Yerevan", "Jerewan" },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
@@ -1411,7 +1427,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
             { "Asia/Yakutsk", Yakutsk },
@@ -1447,7 +1463,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Athens", "Athen" },
             { "Africa/Djibouti", Africa_Eastern },
             { "America/Paramaribo", Suriname },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
             { "Europe/Sofia", Europe_Eastern },
@@ -1469,15 +1485,17 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
             { "Africa/Gaborone", Africa_Central },
+            { "Asia/Pyongyang", Korea },
             { "America/St_Vincent", Atlantic },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akkra" },
             { "PST8PDT", America_Pacific },
             { "timezone.excity.Etc/Unknown", "Njeznate" },
             { "Atlantic/Faeroe", Europe_Western },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.Asia/Riyadh", "Riad" },
             { "America/Yakutat", Alaska },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "Atlantic/Azores", Azores },
             { "Europe/Vienna", Europe_Central },
@@ -1546,10 +1564,19 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Africa/Libreville", Africa_Western },
             { "Africa/Maputo", Africa_Central },
             { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
             { "America/Coral_Harbour", America_Eastern },
             { "Pacific/Marquesas", Marquesas },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Aruba", Atlantic },
             { "timezone.excity.Europe/Luxembourg", "Luxemburg" },
             { "America/North_Dakota/Center", America_Central },
@@ -1700,7 +1727,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "B\u00fcsingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "America/Vancouver", America_Pacific },
             { "Africa/Blantyre", Africa_Central },
@@ -1710,7 +1737,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Vladivostok", "Wladiwostok" },
             { "Africa/Lusaka", Africa_Central },
             { "Asia/Hong_Kong", Hong_Kong },
-            { "timezone.excity.Asia/Macau", "Macao" },
             { "America/Argentina/La_Rioja", Argentina },
             { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
@@ -1757,7 +1783,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Pangnirtung", America_Eastern },
             { "timezone.excity.Atlantic/Cape_Verde", "Kap Verde" },
             { "Asia/Katmandu", Nepal },
-            { "MST", America_Mountain },
             { "Africa/Niamey", Africa_Western },
             { "America/Whitehorse", America_Pacific },
             { "Pacific/Noumea", New_Caledonia },
