@@ -510,6 +510,14 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Volgograd = new String[] {
+               "\u0f56\u0f71\u0f7c\u0f63\u0f0b\u0f42\u0f7c\u0f0b\u0f42\u0f72\u0f62\u0f7a\u0f4c\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "",
+               "\u0f56\u0f71\u0f7c\u0f63\u0f0b\u0f42\u0f7c\u0f0b\u0f42\u0f72\u0f62\u0f7a\u0f4c\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "",
+               "\u0f56\u0f71\u0f7c\u0f63\u0f0b\u0f42\u0f7c\u0f0b\u0f42\u0f72\u0f62\u0f7a\u0f4c\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "",
+            };
         final String[] Iran = new String[] {
                "\u0f68\u0f72\u0f0b\u0f62\u0f71\u0f53\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
@@ -606,12 +614,12 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "\u0f40\u0f7c\u0f0b\u0f63\u0f7c\u0f58\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+        final String[] Australia_Eastern = new String[] {
+               "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
-               "\u0f40\u0f7c\u0f0b\u0f63\u0f7c\u0f58\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
-               "\u0f40\u0f7c\u0f0b\u0f63\u0f7c\u0f58\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -622,12 +630,12 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+        final String[] Colombia = new String[] {
+               "\u0f40\u0f7c\u0f0b\u0f63\u0f7c\u0f58\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f0b\u0f5a\u0f51\u0f0b\u0f63\u0fa1\u0f53\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
-               "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f49\u0f72\u0f53\u0f0b\u0f66\u0fb2\u0f74\u0f44\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "\u0f40\u0f7c\u0f0b\u0f63\u0f7c\u0f58\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f0b\u0f56\u0fb1\u0f71\u0f62\u0f0b\u0f51\u0f74\u0f66\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
-               "\u0f64\u0f62\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f55\u0fb1\u0f7c\u0f42\u0f66\u0f0b\u0f68\u0f71\u0f7c\u0f66\u0f0b\u0f4a\u0fb2\u0f7a\u0f63\u0f0b\u0f63\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
+               "\u0f40\u0f7c\u0f0b\u0f63\u0f7c\u0f58\u0f0b\u0f56\u0fb7\u0f72\u0f0b\u0f61\u0f0b\u0f46\u0f74\u0f0b\u0f5a\u0f7c\u0f51",
                "",
             };
         final String[] Chile = new String[] {
@@ -740,7 +748,16 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -821,7 +838,6 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Africa/Freetown", GMT },
             { "Asia/Macau", China },
             { "Europe/Malta", Europe_Central },
-            { "HST", Hawaii_Aleutian },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
             { "timezone.excity.Africa/Cairo", "\u0f40\u0f71\u0f60\u0f72\u0f0b\u0f62\u0f7c" },
@@ -902,7 +918,7 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
             { "Asia/Yakutsk", Yakutsk },
@@ -931,7 +947,6 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Athens", "\u0f68\u0f7a\u0f0b\u0f50\u0f7a\u0f53\u0f66\u0f0b" },
             { "Africa/Djibouti", Africa_Eastern },
             { "America/Paramaribo", Suriname },
-            { "EST", America_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -946,12 +961,14 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "timezone.excity.Europe/Copenhagen", "\u0f40\u0f7c\u0f0b\u0f54\u0f7a\u0f53\u0f0b\u0f67\u0f7a\u0f0b\u0f42\u0f7a\u0f53" },
             { "Africa/Gaborone", Africa_Central },
+            { "Asia/Pyongyang", Korea },
             { "America/St_Vincent", Atlantic },
             { "Asia/Gaza", Europe_Eastern },
             { "PST8PDT", America_Pacific },
             { "timezone.excity.Etc/Unknown", "\u0f58\u0f0b\u0f64\u0f7a\u0f66\u0f0b\u0f54\u0f60\u0f72\u0f0b\u0f41\u0fb2\u0f7c\u0f58\u0f0b\u0f66\u0fa1\u0f7a" },
             { "Atlantic/Faeroe", Europe_Western },
             { "America/Yakutat", Alaska },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "Atlantic/Azores", Azores },
             { "Europe/Vienna", Europe_Central },
@@ -1000,9 +1017,18 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Africa/Libreville", Africa_Western },
             { "Africa/Maputo", Africa_Central },
             { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
             { "America/Coral_Harbour", America_Eastern },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Cayman", America_Eastern },
@@ -1131,7 +1157,7 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "Indian/Antananarivo", Africa_Eastern },
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "America/Vancouver", America_Pacific },
             { "Africa/Blantyre", Africa_Central },
@@ -1180,7 +1206,6 @@ public class TimeZoneNames_dz extends TimeZoneNamesBundle {
             { "America/Pangnirtung", America_Eastern },
             { "Asia/Katmandu", Nepal },
             { "timezone.excity.America/Goose_Bay", "\u0f42\u0f71\u0f74\u0f66\u0f72\u0f0b \u0f56\u0f60\u0f7a" },
-            { "MST", America_Mountain },
             { "Africa/Niamey", Africa_Western },
             { "America/Whitehorse", America_Pacific },
             { "Asia/Tbilisi", Georgia },
