@@ -73,26 +73,26 @@ public class TimeZoneNames_en_SD extends TimeZoneNamesBundle {
         final String[] Africa_Central = new String[] {
                "Central Africa Time",
                "CAT",
-               "",
-               "",
-               "",
-               "",
+               "Central African Summer Time",
+               "CAST",
+               "Central Africa Time",
+               "CAT",
             };
         final String[] Africa_Eastern = new String[] {
                "East Africa Time",
                "EAT",
-               "",
-               "",
-               "",
-               "",
+               "Eastern African Summer Time",
+               "EAST",
+               "Eastern Africa Time",
+               "EAT",
             };
         final String[] Africa_Southern = new String[] {
                "South Africa Standard Time",
                "SAST",
-               "",
-               "",
-               "",
-               "",
+               "South Africa Summer Time",
+               "SAST",
+               "South Africa Time",
+               "SAT",
             };
         final String[] Africa_Western = new String[] {
                "West Africa Standard Time",
@@ -103,6 +103,16 @@ public class TimeZoneNames_en_SD extends TimeZoneNamesBundle {
                "WAT",
             };
         final Object[][] data = new Object[][] {
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "UTC",
                 new String[] {
                     "",
@@ -118,6 +128,16 @@ public class TimeZoneNames_en_SD extends TimeZoneNamesBundle {
             { "Africa/Lusaka", Africa_Central },
             { "Africa/Gaborone", Africa_Central },
             { "Africa/Maputo", Africa_Central },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Africa/Windhoek", Africa_Central },
             { "Africa/Mbabane", Africa_Southern },
             { "Africa/Mogadishu", Africa_Eastern },
@@ -155,17 +175,16 @@ public class TimeZoneNames_en_SD extends TimeZoneNamesBundle {
                 }
             },
             { "Africa/Kampala", Africa_Eastern },
-            { "Africa/Sao_Tome", Africa_Western },
-            { "Africa/Khartoum", Africa_Central },
             { "Africa/Malabo", Africa_Western },
+            { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
             { "Africa/Ndjamena", Africa_Western },
             { "Africa/Bujumbura", Africa_Central },
             { "Africa/Bangui", Africa_Western },
             { "Africa/Lagos", Africa_Western },
             { "Africa/Brazzaville", Africa_Western },
-            { "Africa/Luanda", Africa_Western },
             { "Africa/Porto-Novo", Africa_Western },
+            { "Africa/Luanda", Africa_Western },
             { "Europe/Astrakhan",
                 new String[] {
                     "",
@@ -210,8 +229,8 @@ public class TimeZoneNames_en_SD extends TimeZoneNamesBundle {
             },
             { "Africa/Maseru", Africa_Southern },
             { "Africa/Kinshasa", Africa_Western },
-            { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Lubumbashi", Africa_Central },
+            { "Africa/Addis_Ababa", Africa_Eastern },
             { "Africa/Djibouti", Africa_Eastern },
             { "Africa/Kigali", Africa_Central },
             { "Indian/Antananarivo", Africa_Eastern },
@@ -225,10 +244,10 @@ public class TimeZoneNames_en_SD extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Niamey", Africa_Western },
             { "Indian/Mayotte", Africa_Eastern },
-            { "Africa/Blantyre", Africa_Central },
+            { "Africa/Niamey", Africa_Western },
             { "Indian/Comoro", Africa_Eastern },
+            { "Africa/Blantyre", Africa_Central },
         };
         return data;
     }
