@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -310,14 +310,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "Folklend adalary wagty",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Butan wagty",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apia standart wagty",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "Apia wagty",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Butan wagty",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauru wagty",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbi\u00fda standart wagty",
+        final String[] Australia_Eastern = new String[] {
+               "G\u00fcndogar Awstrali\u00fda standart wagty",
                "",
-               "Kolumbi\u00fda tomusky wagty",
+               "G\u00fcndogar Awstrali\u00fda tomusky wagty",
                "",
-               "Kolumbi\u00fda wagty",
+               "G\u00fcndogar Awstrali\u00fda wagty",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "G\u00fcndogar Awstrali\u00fda standart wagty",
+        final String[] Colombia = new String[] {
+               "Kolumbi\u00fda standart wagty",
                "",
-               "G\u00fcndogar Awstrali\u00fda tomusky wagty",
+               "Kolumbi\u00fda tomusky wagty",
                "",
-               "G\u00fcndogar Awstrali\u00fda wagty",
+               "Kolumbi\u00fda wagty",
                "",
             };
         final String[] Chile = new String[] {
@@ -891,7 +891,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "",
                "Amazon tomusky wagty",
                "",
-               "Amazan wagty",
+               "Amazon wagty",
                "",
             };
         final String[] Kazakhstan_Eastern = new String[] {
@@ -1038,12 +1038,12 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Demirgazyk-g\u00fcnbatar Meksika standart wagty",
+        final String[] Volgograd = new String[] {
+               "Wolgograd standart wagty",
                "",
-               "Demirgazyk-g\u00fcnbatar Meksika tomusky wagty",
+               "Wolgograd tomusky wagty",
                "",
-               "Demirgazyk-g\u00fcnbatar Meksika wagty",
+               "Wolgograd wagty",
                "",
             };
         final String[] Easter = new String[] {
@@ -1054,6 +1054,14 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "Pasha adasy wagty",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Demirgazyk-g\u00fcnbatar Meksika standart wagty",
+               "",
+               "Demirgazyk-g\u00fcnbatar Meksika tomusky wagty",
+               "",
+               "Demirgazyk-g\u00fcnbatar Meksika wagty",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "D\u00fdumon-d-\u00ddurwil wagty",
                "",
@@ -1190,14 +1198,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                "Brazili\u00fda wagty",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Phen\u00fdan wagty",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Hindistan standart wagty",
                "",
@@ -1228,7 +1228,16 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1312,7 +1321,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nom" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Wankuwer" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1424,12 +1432,12 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "San-Paulu" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "N\u00fdu-\u00ddork" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Akkra" },
             { "timezone.excity.Etc/Unknown", "N\u00e4belli \u015f\u00e4her" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Tule" },
             { "timezone.excity.America/Grand_Turk", "Grand-Terk" },
             { "America/Yakutat", Alaska },
@@ -1490,8 +1498,17 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Keramatly \u00ddelena adasy" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "L\u00fduksemburg" },
             { "America/Cayman", America_Eastern },
@@ -1651,7 +1668,6 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Gus-Be\u00fd" },
             { "timezone.excity.America/Eirunepe", "E\u00fdrunepe" },
             { "timezone.excity.America/Los_Angeles", "Los-Anjeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Ku\u00fdaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1863,7 +1879,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1888,8 +1904,8 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Afiny" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
             { "timezone.excity.America/Indiana/Knox", "Noks, Indiana" },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1911,6 +1927,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "I\u00fderusalim" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Er-Ri\u00fdad" },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangi" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2074,7 +2091,7 @@ public class TimeZoneNames_tk extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Sent-Tomas" },
             { "timezone.excity.Europe/Busingen", "B\u00fduzingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Stambul" },
             { "timezone.excity.Europe/Sarajevo", "Sara\u00fdewo" },
